@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,10 +22,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/libraries.h>
 #include <assets/view.h>
 
+class Webserver_Request;
+
 class Assets_Header
 {
 public:
-  Assets_Header (std::string title, void * webserver_request_in);
+  Assets_Header (const std::string& title, Webserver_Request& webserver_request_in);
   ~Assets_Header ();
   Assets_Header(const Assets_Header&) = delete;
   Assets_Header operator=(const Assets_Header&) = delete;
@@ -36,9 +38,9 @@ public:
   void set_stylesheet ();
   void set_editor_stylesheet ();
   bool display_topbar ();
-  void refresh (int seconds, std::string url = "");
-  void set_fading_menu (std::string html);
-  void add_bread_crumb (std::string item, std::string text);
+  void refresh (int seconds, const std::string& url = "");
+  void set_fading_menu (const std::string& html);
+  void add_bread_crumb (const std::string& item, const std::string& text);
   std::string run ();
 private:
   Assets_View * m_view {nullptr};
@@ -49,7 +51,7 @@ private:
   bool m_display_navigator {false};
   std::string m_included_stylesheet {};
   std::string m_included_editor_stylesheet {};
-  void * m_webserver_request {nullptr};
+  Webserver_Request& m_webserver_request;
   std::string m_fading_menu {};
   std::vector <std::pair <std::string, std::string> > m_bread_crumbs {};
 };
