@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -49,27 +49,23 @@
 #include <pugixml.hpp>
 #endif
 #pragma GCC diagnostic pop
-using namespace std;
-using namespace pugi;
 
 
-string bible_manage_url ()
+std::string bible_manage_url ()
 {
   return "bible/manage";
 }
 
 
-bool bible_manage_acl (void * webserver_request)
+bool bible_manage_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
 }
 
 
-string bible_manage (void * webserver_request)
+std::string bible_manage (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  string page {};
+  std::string page {};
   
   Assets_Header header = Assets_Header (translate("Bibles"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
@@ -77,73 +73,73 @@ string bible_manage (void * webserver_request)
   
   Assets_View view {};
   
-  string success_message {};
-  string error_message {};
+  std::string success_message {};
+  std::string error_message {};
   
   // New Bible handler.
-  if (request->query.count ("new")) {
+  if (webserver_request.query.count ("new")) {
     Dialog_Entry dialog_entry = Dialog_Entry ("manage", translate("Please enter a name for the new empty Bible"), "", "new", "");
     page += dialog_entry.run ();
     return page;
   }
-  if (request->post.count ("new")) {
-    string bible = request->post ["entry"];
+  if (webserver_request.post.count ("new")) {
+    std::string bible = webserver_request.post ["entry"];
     // No underscrore ( _ ) in the name of a Bible because the underscores are used in the searches to separate data.
     bible = filter::strings::replace ("_", "", bible);
-    vector <string> bibles = request->database_bibles ()->getBibles ();
+    const std::vector <std::string> bibles = database::bibles::get_bibles ();
     if (find (bibles.begin(), bibles.end(), bible) != bibles.end()) {
       error_message = translate("This Bible already exists");
     } else {
-      request->database_bibles ()->createBible (bible);
+      database::bibles::create_bible (bible);
       // Check / grant access.
-      if (!access_bible::write (request, bible)) {
-        string me = request->session_logic ()->currentUser ();
+      if (!access_bible::write (webserver_request, bible)) {
+        const std::string& me = webserver_request.session_logic ()->get_username ();
         DatabasePrivileges::set_bible (me, bible, true);
       }
       success_message = translate("The Bible was created");
       // Creating a Bible removes any Sample Bible that might have been there.
       if (!config::logic::demo_enabled ()) {
-        request->database_bibles ()->deleteBible (demo_sample_bible_name ());
+        database::bibles::delete_bible (demo_sample_bible_name ());
         search_logic_delete_bible (demo_sample_bible_name ());
       }
     }
   }
   
   // Copy Bible handler.
-  if (request->query.count ("copy")) {
-    string copy = request->query["copy"];
+  if (webserver_request.query.count ("copy")) {
+    const std::string copy = webserver_request.query["copy"];
     Dialog_Entry dialog_entry = Dialog_Entry ("manage", translate("Please enter a name for where to copy the Bible to"), "", "", "A new Bible will be created with the given name, and the current Bible copied to it");
     dialog_entry.add_query ("origin", copy);
     page += dialog_entry.run ();
     return page;
   }
-  if (request->query.count ("origin")) {
-    string origin = request->query["origin"];
-    if (request->post.count ("entry")) {
-      string destination = request->post["entry"];
+  if (webserver_request.query.count ("origin")) {
+    const std::string origin = webserver_request.query["origin"];
+    if (webserver_request.post.count ("entry")) {
+      std::string destination = webserver_request.post["entry"];
       destination = filter::strings::replace ("_", "", destination); // No underscores in the name.
-      vector <string> bibles = request->database_bibles ()->getBibles ();
+      const std::vector <std::string> bibles = database::bibles::get_bibles ();
       if (find (bibles.begin(), bibles.end(), destination) != bibles.end()) {
         error_message = translate("Cannot copy the Bible because the destination Bible already exists.");
       } else {
         // User needs read access to the original.
-        if (access_bible::read (request, origin)) {
+        if (access_bible::read (webserver_request, origin)) {
           // Copy the Bible data.
-          string origin_folder = request->database_bibles ()->bibleFolder (origin);
-          string destination_folder = request->database_bibles ()->bibleFolder (destination);
+          const std::string origin_folder = database::bibles::bible_folder (origin);
+          const std::string destination_folder = database::bibles::bible_folder (destination);
           filter_url_dir_cp (origin_folder, destination_folder);
           // Copy the Bible search index.
           search_logic_copy_bible (origin, destination);
           // Feedback.
           success_message = translate("The Bible was copied.");
           // Check / grant access to destination Bible.
-          if (!access_bible::write (request, destination)) {
-            string me = request->session_logic ()->currentUser ();
+          if (!access_bible::write (webserver_request, destination)) {
+            const std::string& me = webserver_request.session_logic ()->get_username ();
             DatabasePrivileges::set_bible (me, destination, true);
           }
           // Creating a Bible removes any Sample Bible that might have been there.
           if (!config::logic::demo_enabled ()) {
-            request->database_bibles ()->deleteBible (demo_sample_bible_name ());
+            database::bibles::delete_bible (demo_sample_bible_name ());
             search_logic_delete_bible (demo_sample_bible_name ());
           }
         }
@@ -152,12 +148,12 @@ string bible_manage (void * webserver_request)
   }
 
   // Delete Bible handler.
-  if (request->query.count ("delete")) {
-    string bible = request->query ["delete"];
-    string confirm = request->query ["confirm"];
+  if (webserver_request.query.count ("delete")) {
+    const std::string bible = webserver_request.query ["delete"];
+    const std::string confirm = webserver_request.query ["confirm"];
     if (confirm == "yes") {
       // User needs write access for delete operation.
-      if (access_bible::write (request, bible)) {
+      if (access_bible::write (webserver_request, bible)) {
         bible_logic::delete_bible (bible);
       } else {
         page += assets_page::error ("Insufficient privileges to complete action");
@@ -173,20 +169,21 @@ string bible_manage (void * webserver_request)
 
   view.set_variable ("success_message", success_message);
   view.set_variable ("error_message", error_message);
-  vector <string> bibles = access_bible::bibles (request);
-  xml_document document;
-  for (const auto & bible : bibles) {
-    xml_node li_node = document.append_child ("li");
-    xml_node a_node = li_node.append_child("a");
-    string href = filter_url_build_http_query ("settings", "bible", bible);
+  const std::vector <std::string> bibles = access_bible::bibles (webserver_request);
+  pugi::xml_document document{};
+  for (const auto& bible : bibles) {
+    pugi::xml_node li_node = document.append_child ("li");
+    pugi::xml_node a_node = li_node.append_child("a");
+    const std::string href = filter_url_build_http_query ("settings", "bible", filter_url_urlencode(bible));
     a_node.append_attribute("href") = href.c_str();
     a_node.text().set(bible.c_str());
   }
-  stringstream bibleblock {};
-  document.print(bibleblock, "", format_raw);
+  std::stringstream bibleblock {};
+  document.print(bibleblock, "", pugi::format_raw);
   view.set_variable ("bibleblock", bibleblock.str());
 
-  if (!client_logic_client_enabled ()) view.enable_zone ("server");
+  if (!client_logic_client_enabled ()) 
+    view.enable_zone ("server");
 
   page += view.render ("bb", "manage");
   
