@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -39,66 +39,61 @@
 #include <menu/logic.h>
 #include <tasks/logic.h>
 #include <jobs/index.h>
-using namespace std;
 
 
-string changes_manage_url ()
+std::string changes_manage_url ()
 {
   return "changes/manage";
 }
 
 
-bool changes_manage_acl (void * webserver_request)
+bool changes_manage_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
 }
 
 
-string changes_manage (void * webserver_request)
+std::string changes_manage (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Database_Modifications database_modifications {};
-  
-  
-  string page {};
-  Assets_Header header = Assets_Header (translate("Changes"), request);
+  std::string page {};
+  Assets_Header header = Assets_Header (translate("Changes"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view {};
   
   
-  if (request->query.count("clear")) {
-    string username = request->query["clear"];
+  if (webserver_request.query.count("clear")) {
+    const std::string username = webserver_request.query["clear"];
     // This may take time in case there are many change notifications to clear.
     // If there's 2000+ notifications, it takes a considerable time.
     // For that reason, it starts a background job to clear the change notifications.
     // The app will remain responsive to the user.
     Database_Jobs database_jobs {};
-    int jobId = database_jobs.get_new_id ();
+    const int jobId = database_jobs.get_new_id ();
     database_jobs.set_level (jobId, Filter_Roles::manager ());
     database_jobs.set_start (jobId, translate ("Clearing change notifications."));
-    tasks_logic_queue (DELETECHANGES, {convert_to_string (jobId), username});
-    redirect_browser (request, jobs_index_url () + "?id=" + convert_to_string (jobId));
-    return string();
+    tasks_logic_queue (DELETECHANGES, {std::to_string (jobId), username});
+    redirect_browser (webserver_request, jobs_index_url () + "?id=" + std::to_string (jobId));
+    return std::string();
   }
   
   
-  if (request->query.count("generate")) {
+  if (webserver_request.query.count("generate")) {
     changes_logic_start ();
     view.set_variable ("success", translate ("Will generate lists of changes"));
   }
   
   
   bool notifications {false};
-  vector <string> users = access_user::assignees (webserver_request);
-  for (const auto & user : users) {
-    string any_bible {};
-    vector <int> ids = database_modifications.getNotificationIdentifiers (user, any_bible);
+  std::vector <std::string> users = access_user::assignees (webserver_request);
+  for (const auto& user : users) {
+    std::string any_bible {};
+    const std::vector <int> ids = database::modifications::getNotificationIdentifiers (user, any_bible);
     if (!ids.empty ()) {
       notifications = true;
-      map <string, string> values {};
+      std::map <std::string, std::string> values {};
       values ["user"] = user;
-      values ["count"] = convert_to_string (ids.size ());
+      values ["count"] = std::to_string (ids.size ());
       view.add_iteration ("notifications", values);
     }
   }
