@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -34,53 +34,48 @@
 #include <access/bible.h>
 #include <menu/logic.h>
 #include <checks/settings.h>
-using namespace std;
 
 
-string checks_index_url ()
+std::string checks_index_url ()
 {
   return "checks/index";
 }
 
 
-bool checks_index_acl (void * webserver_request)
+bool checks_index_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
 }
 
 
-string checks_index (void * webserver_request)
+std::string checks_index (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  Database_Check database_check {};
-
-  
-  string page {};
+  std::string page {};
   Assets_Header header = Assets_Header (translate("Checks"), webserver_request);
   header.add_bread_crumb (menu_logic_tools_menu (), menu_logic_tools_text ());
   page = header.run ();
   Assets_View view {};
   
 
-  if (request->query.count ("approve")) {
-    int approve = filter::strings::convert_to_int (request->query["approve"]);
-    database_check.approve (approve);
+  if (webserver_request.query.count ("approve")) {
+    const int approve = filter::strings::convert_to_int (webserver_request.query["approve"]);
+    database::check::approve (approve);
     view.set_variable ("success", translate("The entry was suppressed."));
   }
   
                         
-  if (request->query.count ("delete")) {
-    int erase = filter::strings::convert_to_int (request->query["delete"]);
-    database_check.erase (erase);
+  if (webserver_request.query.count ("delete")) {
+    const int erase = filter::strings::convert_to_int (webserver_request.query["delete"]);
+    database::check::erase (erase);
     view.set_variable ("success", translate("The entry was deleted for just now."));
   }
 
   
   // Get the Bibles the user has write-access to.
-  vector <string> bibles {};
+  std::vector <std::string> bibles {};
   {
-    const vector <string> & all_bibles = request->database_bibles()->getBibles ();
-    for (const auto & bible : all_bibles) {
+    const std::vector <std::string>& all_bibles = database::bibles::get_bibles ();
+    for (const auto& bible : all_bibles) {
       if (access_bible::write (webserver_request, bible)) {
         bibles.push_back (bible);
       }
@@ -88,21 +83,21 @@ string checks_index (void * webserver_request)
   }
   
   
-  stringstream resultblock {};
-  const vector <Database_Check_Hit> & hits = database_check.getHits ();
-  for (const auto & hit : hits) {
-    string bible = hit.bible;
+  std::stringstream resultblock {};
+  const std::vector <database::check::Hit>& hits = database::check::get_hits ();
+  for (const auto& hit : hits) {
+    std::string bible = hit.bible;
     if (find (bibles.begin(), bibles.end (), bible) != bibles.end ()) {
-      int id = hit.rowid;
+      const int id = hit.rowid;
       bible = filter::strings::escape_special_xml_characters (bible);
       int book = hit.book;
       int chapter = hit.chapter;
       int verse = hit.verse;
-      string link = filter_passage_link_for_opening_editor_at (book, chapter, filter::strings::convert_to_string (verse));
-      string information = filter::strings::escape_special_xml_characters (hit.data);
+      const std::string link = filter_passage_link_for_opening_editor_at (book, chapter, std::to_string (verse));
+      const std::string information = filter::strings::escape_special_xml_characters (hit.data);
       resultblock << "<p>\n";
-      resultblock << "<a href=" << quoted("index?approve=" + filter::strings::convert_to_string (id)) << "> ✔ </a>\n";
-      resultblock << "<a href=" << quoted ("index?delete=" + filter::strings::convert_to_string (id)) << ">" << filter::strings::emoji_wastebasket () << "</a>\n";
+      resultblock << "<a href=" << std::quoted("index?approve=" + std::to_string (id)) << "> ✔ </a>\n";
+      resultblock << "<a href=" << std::quoted ("index?delete=" + std::to_string (id)) << ">" << filter::strings::emoji_wastebasket () << "</a>\n";
       resultblock << bible;
       resultblock << " ";
       resultblock << link;
