@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_CHECKS_SUPPRESS_H
-#define INCLUDED_CHECKS_SUPPRESS_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string checks_suppress_url ();
-bool checks_suppress_acl (void * webserver_request);
-string checks_suppress (void * webserver_request);
-
-
-#endif
+std::string checks_suppress_url ();
+bool checks_suppress_acl (Webserver_Request& webserver_request);
+std::string checks_suppress (Webserver_Request& webserver_request);
