@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_CONSISTENCY_POLL_H
-#define INCLUDED_CONSISTENCY_POLL_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string consistency_poll_url ();
-bool consistency_poll_acl (void * webserver_request);
-string consistency_poll (void * webserver_request);
-
-
-#endif
+std::string consistency_poll_url ();
+bool consistency_poll_acl (Webserver_Request& webserver_request);
+std::string consistency_poll (Webserver_Request& webserver_request);
