@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,6 +29,4 @@ public:
   ~Database_Sblgnt ();
   std::vector <std::string> getVerse (int book, int chapter, int verse);
   std::vector <Passage> searchGreek (std::string greek);
-private:
-  sqlite3 * connect ();
 };
