@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -37,39 +37,34 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 // It used to store the default cache in code.
 // That architecture caused 400+ calls to the localization routines during app startup.
 // This cache does not make those calls during app startup.
-map <string, Database_Styles_Item> default_styles_cache;
+std::map <std::string, Database_Styles_Item> default_styles_cache;
 // The memory cache to speed up reading style values.
 // Access a style item like this: cache [stylesheet] [marker].
 // Timing a Bibledit setup phase gave this information:
 // * Before the cache was implemented, fetching styles took 30 seconds (38%) of the total setup time.
 // * After the cache was there, it took 17 seconds (25%) of the total setup time.
-map <string, map <string, Database_Styles_Item>> database_styles_cache;
+std::map <std::string, std::map <std::string, Database_Styles_Item>> database_styles_cache;
 // Cache read and write lock.
-mutex database_styles_cache_mutex;
+std::mutex database_styles_cache_mutex;
 
 
-sqlite3 * Database_Styles::connect ()
-{
-  return database_sqlite_connect ("styles");
-}
+constexpr const auto database_name {"styles"};
 
 
 void Database_Styles::create ()
 {
   // Create database.
-  sqlite3 * db = connect ();
-  string sql;
-  sql = "CREATE TABLE IF NOT EXISTS users ("
-        "user text,"
-        "sheet text"
-        ");";
-  database_sqlite_exec (db, sql);
-  database_sqlite_disconnect (db);
+  SqliteDatabase sql (database_name);
+  sql.set_sql ("CREATE TABLE IF NOT EXISTS users ("
+               "user text,"
+               "sheet text"
+               ");");
+  sql.execute ();
 }
 
 
 // Creates a stylesheet.
-void Database_Styles::createSheet (string sheet)
+void Database_Styles::createSheet (std::string sheet)
 {
   // Folder for storing the stylesheet.
   filter_url_mkdir (sheetfolder (sheet));
@@ -84,9 +79,9 @@ void Database_Styles::createSheet (string sheet)
 
 
 // Returns an array with the available stylesheets.
-vector <string> Database_Styles::getSheets ()
+std::vector <std::string> Database_Styles::getSheets ()
 {
-  vector <string> sheets = filter_url_scandir (databasefolder ());
+  std::vector <std::string> sheets = filter_url_scandir (databasefolder ());
   if (find (sheets.begin (), sheets.end (), styles_logic_standard_sheet ()) == sheets.end ()) {
     sheets.push_back (styles_logic_standard_sheet ());
   }
@@ -96,7 +91,7 @@ vector <string> Database_Styles::getSheets ()
 
 
 // Deletes a stylesheet.
-void Database_Styles::deleteSheet (string sheet)
+void Database_Styles::deleteSheet (std::string sheet)
 {
   if (!sheet.empty ()) filter_url_rmdir (sheetfolder (sheet));
   database_styles_cache_mutex.lock ();
@@ -106,7 +101,7 @@ void Database_Styles::deleteSheet (string sheet)
 
 
 // Adds a marker to the stylesheet.
-void Database_Styles::addMarker (string sheet, string marker)
+void Database_Styles::addMarker (std::string sheet, std::string marker)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   write_item (sheet, item);
@@ -114,7 +109,7 @@ void Database_Styles::addMarker (string sheet, string marker)
 
 
 // Deletes a marker from a stylesheet.
-void Database_Styles::deleteMarker (string sheet, string marker)
+void Database_Styles::deleteMarker (std::string sheet, std::string marker)
 {
   filter_url_unlink (stylefile (sheet, marker));
   database_styles_cache_mutex.lock ();
@@ -124,10 +119,10 @@ void Database_Styles::deleteMarker (string sheet, string marker)
 
 
 // Returns a map with all the markers and the names of the styles in the stylesheet.
-map <string, string> Database_Styles::getMarkersAndNames (string sheet)
+std::map <std::string, std::string> Database_Styles::getMarkersAndNames (std::string sheet)
 {
-  map <string, string> markers_names;
-  vector <string> markers = getMarkers (sheet);
+  std::map <std::string, std::string> markers_names;
+  std::vector <std::string> markers = getMarkers (sheet);
   for (auto marker : markers) {
     Database_Styles_Item item = read_item (sheet, marker);
     markers_names [marker] = item.name;
@@ -137,10 +132,10 @@ map <string, string> Database_Styles::getMarkersAndNames (string sheet)
 
 
 // Returns an array with all the markers of the styles in the stylesheet.
-vector <string> Database_Styles::getMarkers (string sheet)
+std::vector <std::string> Database_Styles::getMarkers (std::string sheet)
 {
   // The markers for this stylesheet.
-  vector <string> markers = filter_url_scandir (sheetfolder (sheet));
+  std::vector <std::string> markers = filter_url_scandir (sheetfolder (sheet));
   if (markers.empty ()) {
     // Check and/or load defaults.
     if (default_styles_cache.empty ()) cache_defaults ();
@@ -156,14 +151,14 @@ vector <string> Database_Styles::getMarkers (string sheet)
 
 
 // Returns an object with all data belonging to a marker.
-Database_Styles_Item Database_Styles::getMarkerData (string sheet, string marker)
+Database_Styles_Item Database_Styles::getMarkerData (std::string sheet, std::string marker)
 {
   return read_item (sheet, marker);
 }
 
 
 // Updates a style's name.
-void Database_Styles::updateName (string sheet, string marker, string name)
+void Database_Styles::updateName (std::string sheet, std::string marker, std::string name)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.name = name;
@@ -172,7 +167,7 @@ void Database_Styles::updateName (string sheet, string marker, string name)
 
 
 // Updates a style's info.
-void Database_Styles::updateInfo (string sheet, string marker, string info)
+void Database_Styles::updateInfo (std::string sheet, std::string marker, std::string info)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.info = info;
@@ -181,7 +176,7 @@ void Database_Styles::updateInfo (string sheet, string marker, string info)
 
 
 // Updates a style's category.
-void Database_Styles::updateCategory (string sheet, string marker, string category)
+void Database_Styles::updateCategory (std::string sheet, std::string marker, std::string category)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.category = category;
@@ -190,7 +185,7 @@ void Database_Styles::updateCategory (string sheet, string marker, string catego
 
 
 // Updates a style's type.
-void Database_Styles::updateType (string sheet, string marker, int type)
+void Database_Styles::updateType (std::string sheet, std::string marker, int type)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.type = type;
@@ -199,7 +194,7 @@ void Database_Styles::updateType (string sheet, string marker, int type)
 
 
 // Updates a style's subtype.
-void Database_Styles::updateSubType (string sheet, string marker, int subtype)
+void Database_Styles::updateSubType (std::string sheet, std::string marker, int subtype)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.subtype = subtype;
@@ -208,7 +203,7 @@ void Database_Styles::updateSubType (string sheet, string marker, int subtype)
 
 
 // Updates a style's font size.
-void Database_Styles::updateFontsize (string sheet, string marker, float fontsize)
+void Database_Styles::updateFontsize (std::string sheet, std::string marker, float fontsize)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.fontsize = fontsize;
@@ -217,7 +212,7 @@ void Database_Styles::updateFontsize (string sheet, string marker, float fontsiz
 
 
 // Updates a style's italic setting.
-void Database_Styles::updateItalic (string sheet, string marker, int italic)
+void Database_Styles::updateItalic (std::string sheet, std::string marker, int italic)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.italic = italic;
@@ -226,7 +221,7 @@ void Database_Styles::updateItalic (string sheet, string marker, int italic)
 
 
 // Updates a style's bold setting.
-void Database_Styles::updateBold (string sheet, string marker, int bold)
+void Database_Styles::updateBold (std::string sheet, std::string marker, int bold)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.bold = bold;
@@ -235,7 +230,7 @@ void Database_Styles::updateBold (string sheet, string marker, int bold)
 
 
 // Updates a style's underline setting.
-void Database_Styles::updateUnderline (string sheet, string marker, int underline)
+void Database_Styles::updateUnderline (std::string sheet, std::string marker, int underline)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.underline = underline;
@@ -244,7 +239,7 @@ void Database_Styles::updateUnderline (string sheet, string marker, int underlin
 
 
 // Updates a style's small caps setting.
-void Database_Styles::updateSmallcaps (string sheet, string marker, int smallcaps)
+void Database_Styles::updateSmallcaps (std::string sheet, std::string marker, int smallcaps)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.smallcaps = smallcaps;
@@ -252,7 +247,7 @@ void Database_Styles::updateSmallcaps (string sheet, string marker, int smallcap
 }
 
 
-void Database_Styles::updateSuperscript (string sheet, string marker, int superscript)
+void Database_Styles::updateSuperscript (std::string sheet, std::string marker, int superscript)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.superscript = superscript;
@@ -260,7 +255,7 @@ void Database_Styles::updateSuperscript (string sheet, string marker, int supers
 }
 
 
-void Database_Styles::updateJustification (string sheet, string marker, int justification)
+void Database_Styles::updateJustification (std::string sheet, std::string marker, int justification)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.justification = justification;
@@ -268,7 +263,7 @@ void Database_Styles::updateJustification (string sheet, string marker, int just
 }
 
 
-void Database_Styles::updateSpaceBefore (string sheet, string marker, float spacebefore)
+void Database_Styles::updateSpaceBefore (std::string sheet, std::string marker, float spacebefore)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.spacebefore = spacebefore;
@@ -276,7 +271,7 @@ void Database_Styles::updateSpaceBefore (string sheet, string marker, float spac
 }
 
 
-void Database_Styles::updateSpaceAfter (string sheet, string marker, float spaceafter)
+void Database_Styles::updateSpaceAfter (std::string sheet, std::string marker, float spaceafter)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.spaceafter = spaceafter;
@@ -284,7 +279,7 @@ void Database_Styles::updateSpaceAfter (string sheet, string marker, float space
 }
 
 
-void Database_Styles::updateLeftMargin (string sheet, string marker, float leftmargin)
+void Database_Styles::updateLeftMargin (std::string sheet, std::string marker, float leftmargin)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.leftmargin = leftmargin;
@@ -292,7 +287,7 @@ void Database_Styles::updateLeftMargin (string sheet, string marker, float leftm
 }
 
 
-void Database_Styles::updateRightMargin (string sheet, string marker, float rightmargin)
+void Database_Styles::updateRightMargin (std::string sheet, std::string marker, float rightmargin)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.rightmargin = rightmargin;
@@ -300,7 +295,7 @@ void Database_Styles::updateRightMargin (string sheet, string marker, float righ
 }
 
 
-void Database_Styles::updateFirstLineIndent (string sheet, string marker, float firstlineindent)
+void Database_Styles::updateFirstLineIndent (std::string sheet, std::string marker, float firstlineindent)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.firstlineindent = firstlineindent;
@@ -308,7 +303,7 @@ void Database_Styles::updateFirstLineIndent (string sheet, string marker, float
 }
 
 
-void Database_Styles::updateSpanColumns (string sheet, string marker, bool spancolumns)
+void Database_Styles::updateSpanColumns (std::string sheet, std::string marker, bool spancolumns)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.spancolumns = spancolumns;
@@ -316,7 +311,7 @@ void Database_Styles::updateSpanColumns (string sheet, string marker, bool spanc
 }
 
 
-void Database_Styles::updateColor (string sheet, string marker, string color)
+void Database_Styles::updateColor (std::string sheet, std::string marker, std::string color)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.color = color;
@@ -324,7 +319,7 @@ void Database_Styles::updateColor (string sheet, string marker, string color)
 }
 
 
-void Database_Styles::updatePrint (string sheet, string marker, bool print)
+void Database_Styles::updatePrint (std::string sheet, std::string marker, bool print)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.print = print;
@@ -332,7 +327,7 @@ void Database_Styles::updatePrint (string sheet, string marker, bool print)
 }
 
 
-void Database_Styles::updateUserbool1 (string sheet, string marker, bool userbool1)
+void Database_Styles::updateUserbool1 (std::string sheet, std::string marker, bool userbool1)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userbool1 = userbool1;
@@ -340,7 +335,7 @@ void Database_Styles::updateUserbool1 (string sheet, string marker, bool userboo
 }
 
 
-void Database_Styles::updateUserbool2 (string sheet, string marker, bool userbool2)
+void Database_Styles::updateUserbool2 (std::string sheet, std::string marker, bool userbool2)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userbool2 = userbool2;
@@ -348,7 +343,7 @@ void Database_Styles::updateUserbool2 (string sheet, string marker, bool userboo
 }
 
 
-void Database_Styles::updateUserbool3 (string sheet, string marker, bool userbool3)
+void Database_Styles::updateUserbool3 (std::string sheet, std::string marker, bool userbool3)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userbool3 = userbool3;
@@ -356,7 +351,7 @@ void Database_Styles::updateUserbool3 (string sheet, string marker, bool userboo
 }
 
 
-void Database_Styles::updateUserint1 (string sheet, string marker, int userint1)
+void Database_Styles::updateUserint1 (std::string sheet, std::string marker, int userint1)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userint1 = userint1;
@@ -364,7 +359,7 @@ void Database_Styles::updateUserint1 (string sheet, string marker, int userint1)
 }
 
 
-void Database_Styles::updateUserint2 (string sheet, string marker, int userint2)
+void Database_Styles::updateUserint2 (std::string sheet, std::string marker, int userint2)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userint2 = userint2;
@@ -372,7 +367,7 @@ void Database_Styles::updateUserint2 (string sheet, string marker, int userint2)
 }
 
 
-void Database_Styles::updateUserstring1 (string sheet, string marker, string userstring1)
+void Database_Styles::updateUserstring1 (std::string sheet, std::string marker, std::string userstring1)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userstring1 = userstring1;
@@ -380,7 +375,7 @@ void Database_Styles::updateUserstring1 (string sheet, string marker, string use
 }
 
 
-void Database_Styles::updateUserstring2 (string sheet, string marker, string userstring2)
+void Database_Styles::updateUserstring2 (std::string sheet, std::string marker, std::string userstring2)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userstring2 = userstring2;
@@ -388,7 +383,7 @@ void Database_Styles::updateUserstring2 (string sheet, string marker, string use
 }
 
 
-void Database_Styles::updateUserstring3 (string sheet, string marker, string userstring3)
+void Database_Styles::updateUserstring3 (std::string sheet, std::string marker, std::string userstring3)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.userstring3 = userstring3;
@@ -396,7 +391,7 @@ void Database_Styles::updateUserstring3 (string sheet, string marker, string use
 }
 
 
-void Database_Styles::updateBackgroundColor (string sheet, string marker, string color)
+void Database_Styles::updateBackgroundColor (std::string sheet, std::string marker, std::string color)
 {
   Database_Styles_Item item = read_item (sheet, marker);
   item.backgroundcolor = color;
@@ -405,25 +400,23 @@ void Database_Styles::updateBackgroundColor (string sheet, string marker, string
 
 
 // Grant $user write access to stylesheet $sheet.
-void Database_Styles::grantWriteAccess (string user, string sheet)
+void Database_Styles::grantWriteAccess (std::string user, std::string sheet)
 {
-  SqliteSQL sql;
+  SqliteDatabase sql (database_name);
   sql.add ("INSERT INTO users VALUES (");
   sql.add (user);
   sql.add (",");
   sql.add (sheet);
   sql.add (");");
-  sqlite3 * db = connect ();
-  database_sqlite_exec (db, sql.sql);
-  database_sqlite_disconnect (db);
+  sql.execute ();
 }
 
 
 // Revoke a $user's write access to stylesheet $sheet.
 // If the $user is empty, then revoke write access of anybody to that $sheet.
-void Database_Styles::revokeWriteAccess (string user, string sheet)
+void Database_Styles::revokeWriteAccess (std::string user, std::string sheet)
 {
-  SqliteSQL sql;
+  SqliteDatabase sql (database_name);
   sql.add ("DELETE FROM users WHERE");
   if (!user.empty ()) {
     sql.add ("user =");
@@ -433,41 +426,37 @@ void Database_Styles::revokeWriteAccess (string user, string sheet)
   sql.add ("sheet =");
   sql.add (sheet);
   sql.add (";");
-  sqlite3 * db = connect ();
-  database_sqlite_exec (db, sql.sql);
-  database_sqlite_disconnect (db);
+  sql.execute ();
 }
 
 
 // Returns true or false depending on whether $user has write access to $sheet.
-bool Database_Styles::hasWriteAccess (string user, string sheet)
+bool Database_Styles::hasWriteAccess (std::string user, std::string sheet)
 {
-  SqliteSQL sql;
+  SqliteDatabase sql (database_name);
   sql.add ("SELECT rowid FROM users WHERE user =");
   sql.add (user);
   sql.add ("AND sheet =");
   sql.add (sheet);
   sql.add (";");
-  sqlite3 * db = connect ();
-  map <string, vector <string> > result = database_sqlite_query (db, sql.sql);
-  database_sqlite_disconnect (db);
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
   return !result["rowid"].empty ();
 }
 
 
-string Database_Styles::databasefolder ()
+std::string Database_Styles::databasefolder ()
 {
   return filter_url_create_root_path ({database_logic_databases (), "styles"});
 }
 
 
-string Database_Styles::sheetfolder (string sheet)
+std::string Database_Styles::sheetfolder (std::string sheet)
 {
   return filter_url_create_path ({databasefolder (), sheet});
 }
 
 
-string Database_Styles::stylefile (string sheet, string marker)
+std::string Database_Styles::stylefile (std::string sheet, std::string marker)
 {
   return filter_url_create_path ({sheetfolder (sheet), marker});
 }
@@ -475,7 +464,7 @@ string Database_Styles::stylefile (string sheet, string marker)
 
 // Reads a style from file.
 // If the file is not there, it takes the default value.
-Database_Styles_Item Database_Styles::read_item (string sheet, string marker)
+Database_Styles_Item Database_Styles::read_item (std::string sheet, std::string marker)
 {
   Database_Styles_Item item;
   
@@ -495,7 +484,7 @@ Database_Styles_Item Database_Styles::read_item (string sheet, string marker)
   
   // Read the item.
   bool take_default = sheet.empty ();
-  string filename;
+  std::string filename;
   if (!take_default) {
     filename = stylefile (sheet, marker);
     if (!file_or_dir_exists (filename)) take_default = true;
@@ -520,36 +509,36 @@ Database_Styles_Item Database_Styles::read_item (string sheet, string marker)
     item.info = translate ("Information");
   } else {
     // Read the style from file.
-    string contents = filter_url_file_get_contents (filename);
-    vector <string> lines = filter_string_explode (contents, '\n');
+    std::string contents = filter_url_file_get_contents (filename);
+    std::vector <std::string> lines = filter::strings::explode (contents, '\n');
     for (unsigned int i = 0; i < lines.size(); i++) {
       if (i == 0)  item.marker = lines [i];
       if (i == 1)  item.name = lines [i];
       if (i == 2)  item.info = lines [i];
       if (i == 3)  item.category = lines [i];
-      if (i == 4)  item.type = convert_to_int (lines [i]);
-      if (i == 5)  item.subtype = convert_to_int (lines [i]);
-      if (i == 6)  item.fontsize = convert_to_float (lines [i]);
-      if (i == 7)  item.italic = convert_to_int (lines [i]);
-      if (i == 8)  item.bold = convert_to_int (lines [i]);
-      if (i == 9)  item.underline = convert_to_int (lines [i]);
-      if (i == 10) item.smallcaps = convert_to_int (lines [i]);
-      if (i == 11) item.superscript = convert_to_int (lines [i]);
-      if (i == 12) item.justification = convert_to_int (lines [i]);
-      if (i == 13) item.spacebefore = convert_to_float (lines [i]);
-      if (i == 14) item.spaceafter = convert_to_float (lines [i]);
-      if (i == 15) item.leftmargin = convert_to_float (lines [i]);
-      if (i == 16) item.rightmargin = convert_to_float (lines [i]);
-      if (i == 17) item.firstlineindent = convert_to_float (lines [i]);
-      if (i == 18) item.spancolumns = convert_to_bool (lines [i]);
+      if (i == 4)  item.type = filter::strings::convert_to_int (lines [i]);
+      if (i == 5)  item.subtype = filter::strings::convert_to_int (lines [i]);
+      if (i == 6)  item.fontsize = filter::strings::convert_to_float (lines [i]);
+      if (i == 7)  item.italic = filter::strings::convert_to_int (lines [i]);
+      if (i == 8)  item.bold = filter::strings::convert_to_int (lines [i]);
+      if (i == 9)  item.underline = filter::strings::convert_to_int (lines [i]);
+      if (i == 10) item.smallcaps = filter::strings::convert_to_int (lines [i]);
+      if (i == 11) item.superscript = filter::strings::convert_to_int (lines [i]);
+      if (i == 12) item.justification = filter::strings::convert_to_int (lines [i]);
+      if (i == 13) item.spacebefore = filter::strings::convert_to_float (lines [i]);
+      if (i == 14) item.spaceafter = filter::strings::convert_to_float (lines [i]);
+      if (i == 15) item.leftmargin = filter::strings::convert_to_float (lines [i]);
+      if (i == 16) item.rightmargin = filter::strings::convert_to_float (lines [i]);
+      if (i == 17) item.firstlineindent = filter::strings::convert_to_float (lines [i]);
+      if (i == 18) item.spancolumns = filter::strings::convert_to_bool (lines [i]);
       if (i == 19) item.color = lines [i];
-      if (i == 20) item.print = convert_to_bool (lines [i]);
-      if (i == 21) item.userbool1 = convert_to_bool (lines [i]);
-      if (i == 22) item.userbool2 = convert_to_bool (lines [i]);
-      if (i == 23) item.userbool3 = convert_to_bool (lines [i]);
-      if (i == 24) item.userint1 = convert_to_int (lines [i]);
-      if (i == 25) item.userint2 = convert_to_int (lines [i]);
-      if (i == 26) item.userint3 = convert_to_int (lines [i]);
+      if (i == 20) item.print = filter::strings::convert_to_bool (lines [i]);
+      if (i == 21) item.userbool1 = filter::strings::convert_to_bool (lines [i]);
+      if (i == 22) item.userbool2 = filter::strings::convert_to_bool (lines [i]);
+      if (i == 23) item.userbool3 = filter::strings::convert_to_bool (lines [i]);
+      if (i == 24) item.userint1 = filter::strings::convert_to_int (lines [i]);
+      if (i == 25) item.userint2 = filter::strings::convert_to_int (lines [i]);
+      if (i == 26) item.userint3 = filter::strings::convert_to_int (lines [i]);
       if (i == 27) item.userstring1 = lines [i];
       if (i == 28) item.userstring2 = lines [i];
       if (i == 29) item.userstring3 = lines [i];
@@ -567,51 +556,51 @@ Database_Styles_Item Database_Styles::read_item (string sheet, string marker)
 }
 
 
-void Database_Styles::write_item (string sheet, Database_Styles_Item & item)
+void Database_Styles::write_item (std::string sheet, Database_Styles_Item & item)
 {
   // The style is saved to file here.
   // When the style is loaded again from file, the various parts of the style are loaded by line number.
   // Therefore it cannot handle strings with new lines in them.
   // Remove the new lines where appropriate.
-  item.name = filter_string_str_replace ("\n", " ", item.name);
-  item.name = filter_string_str_replace ("\r", " ", item.name);
-  item.info = filter_string_str_replace ("\n", " ", item.info);
-  item.info = filter_string_str_replace ("\r", " ", item.info);
+  item.name = filter::strings::replace ("\n", " ", item.name);
+  item.name = filter::strings::replace ("\r", " ", item.name);
+  item.info = filter::strings::replace ("\n", " ", item.info);
+  item.info = filter::strings::replace ("\r", " ", item.info);
   // Load the lines.
-  vector <string> lines;
+  std::vector <std::string> lines;
   lines.push_back (item.marker);
   lines.push_back (item.name);
   lines.push_back (item.info);
   lines.push_back (item.category);
-  lines.push_back (convert_to_string (item.type));
-  lines.push_back (convert_to_string (item.subtype));
-  lines.push_back (convert_to_string (item.fontsize));
-  lines.push_back (convert_to_string (item.italic));
-  lines.push_back (convert_to_string (item.bold));
-  lines.push_back (convert_to_string (item.underline));
-  lines.push_back (convert_to_string (item.smallcaps));
-  lines.push_back (convert_to_string (item.superscript));
-  lines.push_back (convert_to_string (item.justification));
-  lines.push_back (convert_to_string (item.spacebefore));
-  lines.push_back (convert_to_string (item.spaceafter));
-  lines.push_back (convert_to_string (item.leftmargin));
-  lines.push_back (convert_to_string (item.rightmargin));
-  lines.push_back (convert_to_string (item.firstlineindent));
-  lines.push_back (convert_to_string (item.spancolumns));
+  lines.push_back (std::to_string (item.type));
+  lines.push_back (std::to_string (item.subtype));
+  lines.push_back (filter::strings::convert_to_string (item.fontsize));
+  lines.push_back (std::to_string (item.italic));
+  lines.push_back (std::to_string (item.bold));
+  lines.push_back (std::to_string (item.underline));
+  lines.push_back (std::to_string (item.smallcaps));
+  lines.push_back (std::to_string (item.superscript));
+  lines.push_back (std::to_string (item.justification));
+  lines.push_back (filter::strings::convert_to_string (item.spacebefore));
+  lines.push_back (filter::strings::convert_to_string (item.spaceafter));
+  lines.push_back (filter::strings::convert_to_string (item.leftmargin));
+  lines.push_back (filter::strings::convert_to_string (item.rightmargin));
+  lines.push_back (filter::strings::convert_to_string (item.firstlineindent));
+  lines.push_back (filter::strings::convert_to_string (item.spancolumns));
   lines.push_back (item.color);
-  lines.push_back (convert_to_string (item.print));
-  lines.push_back (convert_to_string (item.userbool1));
-  lines.push_back (convert_to_string (item.userbool2));
-  lines.push_back (convert_to_string (item.userbool3));
-  lines.push_back (convert_to_string (item.userint1));
-  lines.push_back (convert_to_string (item.userint2));
-  lines.push_back (convert_to_string (item.userint3));
+  lines.push_back (filter::strings::convert_to_string (item.print));
+  lines.push_back (filter::strings::convert_to_string (item.userbool1));
+  lines.push_back (filter::strings::convert_to_string (item.userbool2));
+  lines.push_back (filter::strings::convert_to_string (item.userbool3));
+  lines.push_back (std::to_string (item.userint1));
+  lines.push_back (std::to_string (item.userint2));
+  lines.push_back (std::to_string (item.userint3));
   lines.push_back (item.userstring1);
   lines.push_back (item.userstring2);
   lines.push_back (item.userstring3);
   lines.push_back (item.backgroundcolor);
   // Save.
-  string data = filter_string_implode (lines, "\n");
+  std::string data = filter::strings::implode (lines, "\n");
   filter_url_file_put_contents (stylefile (sheet, item.marker), data);
   // Clear cache.
   database_styles_cache_mutex.lock ();
@@ -670,34 +659,3 @@ void Database_Styles::cache_defaults ()
 }
 
 
-Database_Styles_Item::Database_Styles_Item ()
-{
-  // Defaults.
-  type = 0;
-  subtype = 0;
-  fontsize = 12;
-  italic = 0;
-  bold = 0;
-  underline = 0;
-  smallcaps = 0;
-  superscript = 0;
-  justification = 0;
-  spacebefore = 0;
-  spaceafter = 0;
-  leftmargin = 0;
-  rightmargin = 0;
-  firstlineindent = 0;
-  spancolumns = false;
-  color = "#000000";
-  print = false;
-  userbool1 = false;
-  userbool2 = false;
-  userbool3 = false;
-  userint1 = 0;
-  userint2 = 0;
-  userint3 = 0;
-  userstring1 = "";
-  userstring2 = "";
-  userstring3 = "";
-  backgroundcolor = "#FFFFFF";
-}
