@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/logs.h>
 #include <versification/logic.h>
 #include <locale/logic.h>
-using namespace std;
 
 
 // This is a database for the versification systems.
@@ -37,63 +36,59 @@ using namespace std;
 // See https://github.com/openscriptures/BibleOrgSys/
 
 
-sqlite3 * Database_Versifications::connect ()
-{
-  return database_sqlite_connect ("versifications");
-}
+constexpr const auto versifications {"versifications"};
 
 
 void Database_Versifications::create ()
 {
-  sqlite3 * db = connect ();
-  string sql;
-  sql = 
-    "CREATE TABLE IF NOT EXISTS names ("
-    " system integer,"
-    " name text"
-    ");";
-  database_sqlite_exec (db, sql);
-  sql = 
-    "CREATE TABLE IF NOT EXISTS data ("
-    " system integer,"
-    " book integer,"
-    " chapter integer,"
-    " verse integer"
-    ");";
-  database_sqlite_exec (db, sql);
-  database_sqlite_disconnect (db);
+  SqliteDatabase sql (versifications);
+  sql.set_sql ("CREATE TABLE IF NOT EXISTS names ("
+               " system integer,"
+               " name text"
+               ");");
+  sql.execute ();
+  sql.set_sql ("CREATE TABLE IF NOT EXISTS data ("
+               " system integer,"
+               " book integer,"
+               " chapter integer,"
+               " verse integer"
+               ");");
+  sql.execute ();
 }
 
 
 void Database_Versifications::optimize ()
 {
-  sqlite3 * db = connect ();
-  database_sqlite_exec (db, "VACUUM;");
-  database_sqlite_exec (db, "VACUUM;");
-  database_sqlite_disconnect (db);
+  SqliteDatabase sql (versifications);
+  sql.set_sql ("VACUUM;");
+  sql.execute ();
 }
 
 
 // Import data.
-void Database_Versifications::input (const string& contents, const string& name)
+void Database_Versifications::input (const std::string& contents, const std::string& name)
 {
   // Delete old system if it is there, and create new one.
   erase (name);
   int id = createSystem (name);
 
-  sqlite3 * db = connect ();
-  database_sqlite_exec (db, "PRAGMA temp_store = MEMORY;");
-  database_sqlite_exec (db, "PRAGMA synchronous = OFF;");
-  database_sqlite_exec (db, "PRAGMA journal_mode = OFF;");
-  database_sqlite_exec (db, "BEGIN;");
-  
-  vector <string> lines = filter::strings::explode (contents, '\n');
+  SqliteDatabase sql (versifications);
+  sql.set_sql ("PRAGMA temp_store = MEMORY;");
+  sql.execute();
+  sql.set_sql ("PRAGMA synchronous = OFF;");
+  sql.execute();
+  sql.set_sql ("PRAGMA journal_mode = OFF;");
+  sql.execute();
+  sql.set_sql ("BEGIN;");
+  sql.execute();
+
+  std::vector <std::string> lines = filter::strings::explode (contents, '\n');
   for (auto line : lines) {
     line = filter::strings::trim (line);
     if (line.empty ()) continue;
     // The line will be something similar to this: 1 Corinthians 1:31
     // Split the passage entry on the colon (:) to get the verse.
-    vector <string> bits = filter::strings::explode(line, ':');
+    std::vector <std::string> bits = filter::strings::explode(line, ':');
     if (bits.size() != 2) continue;
     int verse = filter::strings::convert_to_int(bits[1]);
     // Split the first bit on the spaces and get the last item as the chapter.
@@ -102,7 +97,7 @@ void Database_Versifications::input (const string& contents, const string& name)
     int chapter = filter::strings::convert_to_int(bits[bits.size()-1]);
     // Remove the last bit so it remains with the book, and get that book.
     bits.pop_back();
-    string passage_book_string = filter::strings::implode(bits, " ");
+    std::string passage_book_string = filter::strings::implode(bits, " ");
     int book = static_cast<int>(database::books::get_id_from_english(passage_book_string));
     // Check result.
     if ((book == 0) || (chapter == 0)) {
@@ -110,7 +105,7 @@ void Database_Versifications::input (const string& contents, const string& name)
       continue;
     }
     // Store result.
-    SqliteSQL sql = SqliteSQL ();
+    sql.clear();
     sql.add ("INSERT INTO data (system, book, chapter, verse) VALUES (");
     sql.add (id);
     sql.add (",");
@@ -120,23 +115,23 @@ void Database_Versifications::input (const string& contents, const string& name)
     sql.add (",");
     sql.add (verse);
     sql.add (");");
-    database_sqlite_exec (db, sql.sql);
+    sql.execute ();
   }
   
-  database_sqlite_exec (db, "COMMIT;");
-  database_sqlite_disconnect (db);
+  sql.set_sql ("COMMIT;");
+  sql.execute();
 }
 
 
 // Export data.
-string Database_Versifications::output (const string& name)
+std::string Database_Versifications::output (const std::string& name)
 {
-  vector <string> lines;
-  vector <Passage> versification_data = getBooksChaptersVerses (name);
+  std::vector <std::string> lines;
+  std::vector <Passage> versification_data = getBooksChaptersVerses (name);
   for (Passage & passage : versification_data) {
-    string line = database::books::get_english_from_id (static_cast<book_id>(passage.m_book));
+    std::string line = database::books::get_english_from_id (static_cast<book_id>(passage.m_book));
     line.append (" ");
-    line.append (filter::strings::convert_to_string (passage.m_chapter));
+    line.append (std::to_string (passage.m_chapter));
     line.append (":");
     line.append (passage.m_verse);
     lines.push_back (line);
@@ -146,39 +141,34 @@ string Database_Versifications::output (const string& name)
 
 
 // Delete a versification system.
-void Database_Versifications::erase (const string& name)
+void Database_Versifications::erase (const std::string& name)
 {
   int id = getID (name);
 
-  SqliteSQL sql1 = SqliteSQL ();
-  sql1.add ("DELETE FROM names WHERE system =");
-  sql1.add (id);
-  sql1.add (";");
+  SqliteDatabase sql (versifications);
+  sql.add ("DELETE FROM names WHERE system =");
+  sql.add (id);
+  sql.add (";");
+  sql.execute ();
 
-  SqliteSQL sql2 = SqliteSQL ();
-  sql2.add ("DELETE FROM data WHERE system =");
-  sql2.add (id);
-  sql2.add (";");
-
-  sqlite3 * db = connect ();
-  database_sqlite_exec (db, sql1.sql);
-  database_sqlite_exec (db, sql2.sql);
-  database_sqlite_disconnect (db);
+  sql.clear();
+  sql.add ("DELETE FROM data WHERE system =");
+  sql.add (id);
+  sql.add (";");
+  sql.execute ();
 }
 
 
 // Returns the ID for a named versification system.
-int Database_Versifications::getID (const string& name)
+int Database_Versifications::getID (const std::string& name)
 {
-  SqliteSQL sql = SqliteSQL ();
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT system FROM names WHERE name =");
   sql.add (name);
   sql.add (";");
-  sqlite3 * db = connect ();
-  vector <string> systems = database_sqlite_query (db, sql.sql) ["system"];
-  database_sqlite_disconnect (db);
+  const std::vector <std::string> systems = sql.query () ["system"];
   if (!systems.empty()) {
-    auto id = systems[0];
+    const auto id = systems.at(0);
     return filter::strings::convert_to_int (id);
   }
   return 0;
@@ -187,7 +177,7 @@ int Database_Versifications::getID (const string& name)
 
 // Creates a new empty versification system.
 // Returns the new ID.
-int Database_Versifications::createSystem (const string& name)
+int Database_Versifications::createSystem (const std::string& name)
 {
   // If the versification system already exists, return its ID.
   int id = getID (name);
@@ -196,52 +186,50 @@ int Database_Versifications::createSystem (const string& name)
   }
   // Get the first free ID starting from 1000 (except when creating the default systems).
   id = 0;
-  sqlite3 * db = connect ();
-  vector <string> systems = database_sqlite_query (db, "SELECT system FROM names ORDER BY system DESC LIMIT 1;") ["system"];
-  for (auto & system : systems) {
+  SqliteDatabase sql (versifications);
+  sql.set_sql ("SELECT system FROM names ORDER BY system DESC LIMIT 1;");
+  const std::vector <std::string> systems = sql.query () ["system"];
+  for (const auto& system : systems) {
     id = filter::strings::convert_to_int (system);
   }
   id++;
   if (!creating_defaults) if (id < 1000) id = 1000;
   // Create the empty system.
-  SqliteSQL sql = SqliteSQL ();
+  sql.clear();
   sql.add ("INSERT INTO names VALUES (");
   sql.add (id);
   sql.add (",");
   sql.add (name);
   sql.add (");");
-  database_sqlite_exec (db, sql.sql);
-  database_sqlite_disconnect (db);
+  sql.execute ();
   // Return new ID.
   return id;
 }
 
 
 // Returns an array of the available versification systems.
-vector <string> Database_Versifications::getSystems ()
+std::vector <std::string> Database_Versifications::getSystems ()
 {
-  sqlite3 * db = connect ();
-  vector <string> systems = database_sqlite_query (db, "SELECT name FROM names ORDER BY name ASC;") ["name"];
-  database_sqlite_disconnect (db);
+  SqliteDatabase sql (versifications);
+  sql.set_sql ("SELECT name FROM names ORDER BY name ASC;");
+  const std::vector <std::string> systems = sql.query () ["name"];
   return systems;
 }
 
 
 // Returns the books, chapters, verses for the given versification system.
-vector <Passage> Database_Versifications::getBooksChaptersVerses (const string& name)
+std::vector <Passage> Database_Versifications::getBooksChaptersVerses (const std::string& name)
 {
-  vector <Passage> data;
-  int id = getID (name);
-  SqliteSQL sql = SqliteSQL ();
+  std::vector <Passage> data;
+  const int id = getID (name);
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT book, chapter, verse FROM data WHERE system =");
   sql.add (id);
   sql.add ("ORDER BY book, chapter, verse ASC;");
-  sqlite3 * db = connect ();
-  map <string, vector <string> > result = database_sqlite_query (db, sql.sql);
-  database_sqlite_disconnect (db);
-  vector <string> books = result ["book"];
-  vector <string> chapters = result ["chapter"];
-  vector <string> verses = result ["verse"];
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
+  const std::vector <std::string> books = result ["book"];
+  const std::vector <std::string> chapters = result ["chapter"];
+  const std::vector <std::string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
     Passage passage;
     passage.m_book = filter::strings::convert_to_int (books [i]);
@@ -253,18 +241,16 @@ vector <Passage> Database_Versifications::getBooksChaptersVerses (const string&
 }
 
 
-vector <int> Database_Versifications::getBooks (const string& name)
+std::vector <int> Database_Versifications::getBooks (const std::string& name)
 {
-  vector <int> books;
-  int id = getID (name);
-  SqliteSQL sql = SqliteSQL ();
+  std::vector <int> books;
+  const int id = getID (name);
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT DISTINCT book FROM data WHERE system =");
   sql.add (id);
   sql.add ("ORDER BY book ASC;");
-  sqlite3 * db = connect ();
-  vector <string> sbooks = database_sqlite_query (db, sql.sql) ["book"];
-  database_sqlite_disconnect (db);
-  for (auto & book : sbooks) {
+  std::vector <std::string> sbooks = sql.query () ["book"];
+  for (const auto& book : sbooks) {
     books.push_back (filter::strings::convert_to_int (book));
   }
   return books;
@@ -273,32 +259,30 @@ vector <int> Database_Versifications::getBooks (const string& name)
 
 // This returns all the chapters in book of versification system name.
 // include0: Includes chapter 0 also.
-vector <int> Database_Versifications::getChapters (const string& name, int book, bool include0)
+std::vector <int> Database_Versifications::getChapters (const std::string& name, int book, bool include0)
 {
-  vector <int> chapters;
+  std::vector <int> chapters;
   if (include0) chapters.push_back (0);
-  int id = this->getID (name);
-  SqliteSQL sql = SqliteSQL ();
+  int id = getID (name);
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT DISTINCT chapter FROM data WHERE system =");
   sql.add (id);
   sql.add ("AND book =");
   sql.add (book);
   sql.add ("ORDER BY chapter ASC;");
-  sqlite3 * db = connect ();
-  vector <string> schapters = database_sqlite_query (db, sql.sql) ["chapter"];
-  database_sqlite_disconnect (db);
-  for (auto & chapter : schapters) {
+  std::vector <std::string> schapters = sql.query () ["chapter"];
+  for (const auto& chapter : schapters) {
     chapters.push_back (filter::strings::convert_to_int (chapter));
   }
   return chapters;
 }
 
 
-vector <int> Database_Versifications::getVerses (const string& name, int book, int chapter)
+std::vector <int> Database_Versifications::getVerses (const std::string& name, int book, int chapter)
 {
-  vector <int> verses;
+  std::vector <int> verses;
   int id = getID (name);
-  SqliteSQL sql = SqliteSQL ();
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT DISTINCT verse FROM data WHERE system =");
   sql.add (id);
   sql.add ("AND book =");
@@ -306,11 +290,9 @@ vector <int> Database_Versifications::getVerses (const string& name, int book, i
   sql.add ("AND chapter =");
   sql.add (chapter);
   sql.add ("ORDER BY verse ASC;");
-  sqlite3 * db = connect ();
-  vector <string> sverses = database_sqlite_query (db, sql.sql) ["verse"];
-  database_sqlite_disconnect (db);
-  for (auto & verse : sverses) {
-    int maxverse = filter::strings::convert_to_int (verse);
+  std::vector <std::string> sverses = sql.query () ["verse"];
+  for (const auto& verse : sverses) {
+    const int maxverse = filter::strings::convert_to_int (verse);
     for (int i = 0; i <= maxverse; i++) {
       verses.push_back (i);
     }
@@ -323,16 +305,17 @@ vector <int> Database_Versifications::getVerses (const string& name, int book, i
 
 void Database_Versifications::defaults ()
 {
-  sqlite3 * db = connect ();
-  database_sqlite_exec (db, "DELETE FROM names WHERE system < 1000;");
-  database_sqlite_exec (db, "DELETE FROM data WHERE system < 1000;");
-  database_sqlite_disconnect (db);
+  SqliteDatabase sql (versifications);
+  sql.set_sql ("DELETE FROM names WHERE system < 1000;");
+  sql.execute();
+  sql.set_sql ("DELETE FROM data WHERE system < 1000;");
+  sql.execute();
 
   creating_defaults = true;
-  vector <string> names = versification_logic_names ();
+  std::vector <std::string> names = versification_logic_names ();
   for (auto name : names) {
     // Read the file contents.
-    string contents = versification_logic_data (name);
+    std::string contents = versification_logic_data (name);
     // Due to a need of obfuscating "Bible" and similar,
     // If a versification system is called "Staten Bible",
     // it will be stored in the file system as "Staten Bb",
@@ -347,15 +330,13 @@ void Database_Versifications::defaults ()
 
 
 // This returns all possible books in any versification system.
-vector <int> Database_Versifications::getMaximumBooks ()
+std::vector <int> Database_Versifications::getMaximumBooks ()
 {
-  vector <int> books;
-  SqliteSQL sql = SqliteSQL ();
+  std::vector <int> books;
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT DISTINCT book FROM data ORDER BY book ASC;");
-  sqlite3 * db = connect ();
-  vector <string> sbooks = database_sqlite_query (db, sql.sql) ["book"];
-  database_sqlite_disconnect (db);
-  for (auto & book : sbooks) {
+  const std::vector <std::string> sbooks = sql.query () ["book"];
+  for (const auto& book : sbooks) {
     books.push_back (filter::strings::convert_to_int (book));
   }
   return books;
@@ -363,18 +344,16 @@ vector <int> Database_Versifications::getMaximumBooks ()
 
 
 // This returns all possible chapters in a book of any versification system.
-vector <int> Database_Versifications::getMaximumChapters (int book)
+std::vector <int> Database_Versifications::getMaximumChapters (int book)
 {
-  vector <int> chapters;
+  std::vector <int> chapters;
   chapters.push_back (0);
-  SqliteSQL sql = SqliteSQL ();
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT DISTINCT chapter FROM data WHERE book =");
   sql.add (book);
   sql.add ("ORDER BY chapter ASC;");
-  sqlite3 * db = connect ();
-  vector <string> schapters = database_sqlite_query (db, sql.sql) ["chapter"];
-  database_sqlite_disconnect (db);
-  for (auto & chapter : schapters) {
+  const std::vector <std::string> schapters = sql.query () ["chapter"];
+  for (const auto& chapter : schapters) {
     chapters.push_back (filter::strings::convert_to_int (chapter));
   }
   return chapters;
@@ -382,20 +361,18 @@ vector <int> Database_Versifications::getMaximumChapters (int book)
 
 
 // This returns all possible verses in a book / chapter of any versification system.
-vector <int> Database_Versifications::getMaximumVerses (int book, int chapter)
+std::vector <int> Database_Versifications::getMaximumVerses (int book, int chapter)
 {
-  vector <int> verses;
-  SqliteSQL sql = SqliteSQL ();
+  std::vector <int> verses;
+  SqliteDatabase sql (versifications);
   sql.add ("SELECT DISTINCT verse FROM data WHERE book =");
   sql.add (book);
   sql.add ("AND chapter =");
   sql.add (chapter);
   sql.add ("ORDER BY verse ASC;");
-  sqlite3 * db = connect ();
-  vector <string> sverses = database_sqlite_query (db, sql.sql) ["verse"];
-  database_sqlite_disconnect (db);
-  for (auto & verse : sverses) {
-    int maxverse = filter::strings::convert_to_int (verse);
+  const std::vector <std::string> sverses = sql.query () ["verse"];
+  for (const auto& verse : sverses) {
+    const int maxverse = filter::strings::convert_to_int (verse);
     for (int i = 0; i <= maxverse; i++) {
       verses.push_back (i);
     }
