@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,39 +30,36 @@
 #include <locale/translate.h>
 #include <assets/view.h>
 #include <access/bible.h>
-using namespace std;
 
 
-string edit_edit_url ()
+std::string edit_edit_url ()
 {
   return "edit/edit";
 }
 
 
-bool edit_edit_acl (void * webserver_request)
+bool edit_edit_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
   auto [read, write] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string edit_edit (void * webserver_request)
+std::string edit_edit (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  
-  string passage_query = request->query ["passage"];
+  std::string passage_query = webserver_request.query ["passage"];
   Passage passage = filter_integer_to_passage (filter::strings::convert_to_int (passage_query));
-  Ipc_Focus::set (request, passage.m_book, passage.m_chapter, filter::strings::convert_to_int (passage.m_verse));
-  Navigation_Passage::record_history (request, passage.m_book, passage.m_chapter, filter::strings::convert_to_int (passage.m_verse));
-  
+  Ipc_Focus::set (webserver_request, passage.m_book, passage.m_chapter, filter::strings::convert_to_int (passage.m_verse));
+  Navigation_Passage::record_history (webserver_request, passage.m_book, passage.m_chapter, filter::strings::convert_to_int (passage.m_verse));
   
   // Check whether a Bible editor is alive.
-  int timestamp = request->database_config_user()->getLiveBibleEditor ();
+  int timestamp = webserver_request.database_config_user()->getLiveBibleEditor ();
   bool alive = (timestamp > (filter::date::seconds_since_epoch () - 5));
   
+  if (alive) 
+    return translate ("The passage has been opened in the existing Bible editor");
   
-  if (alive) return translate ("The passage has been opened in the existing Bible editor");
   return R"(<a href="../editone2/index">)" + translate ("Open a Bible editor to edit the passage") + "</a>";
 }
