@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -41,47 +41,42 @@
 #include <sendreceive/logic.h>
 
 
-string editone2_save_url ()
+std::string editone2_save_url ()
 {
   return "editone2/save";
 }
 
 
-bool editone2_save_acl (void * webserver_request)
+bool editone2_save_acl (Webserver_Request& webserver_request)
 {
-  if (config_logic_indonesian_cloud_free ()) {
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
     return true;
-  }
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
-  auto [ read, write ] = AccessBible::Any (webserver_request);
+  auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string editone2_save (void * webserver_request)
+std::string editone2_save (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  
   // Check on information about where to save the verse.
-  bool save = (request->post.count ("bible") && request->post.count ("book") && request->post.count ("chapter") && request->post.count ("verse") && request->post.count ("html"));
+  bool save = (webserver_request.post.count ("bible") && webserver_request.post.count ("book") && webserver_request.post.count ("chapter") && webserver_request.post.count ("verse") && webserver_request.post.count ("html"));
   if (!save) {
     return translate("Don't know where to save");
   }
 
   
-  string bible = request->post["bible"];
-  int book = convert_to_int (request->post["book"]);
-  int chapter = convert_to_int (request->post["chapter"]);
-  int verse = convert_to_int (request->post["verse"]);
-  string html = request->post["html"];
-  string checksum = request->post["checksum"];
-  string unique_id = request->post ["id"];
+  std::string bible = webserver_request.post["bible"];
+  int book = filter::strings::convert_to_int (webserver_request.post["book"]);
+  int chapter = filter::strings::convert_to_int (webserver_request.post["chapter"]);
+  int verse = filter::strings::convert_to_int (webserver_request.post["verse"]);
+  std::string html = webserver_request.post["html"];
+  std::string checksum = webserver_request.post["checksum"];
+  std::string unique_id = webserver_request.post ["id"];
 
   
   // Checksum.
-  if (Checksum_Logic::get (html) != checksum) {
-    request->response_code = 409;
+  if (checksum_logic::get (html) != checksum) {
+    webserver_request.response_code = 409;
     return translate ("Checksum error");
   }
 
@@ -91,35 +86,35 @@ string editone2_save (void * webserver_request)
 
   
   // Check there's anything to save at all.
-  html = filter_string_trim (html);
+  html = filter::strings::trim (html);
   if (html.empty ()) {
     return translate ("Nothing to save");
   }
   
   
   // Check on valid UTF-8.
-  if (!unicode_string_is_valid (html)) {
+  if (!filter::strings::unicode_string_is_valid (html)) {
     return translate ("Cannot save: Needs Unicode");
   }
   
   
-  if (!AccessBible::BookWrite (request, string(), bible, book)) {
+  if (!access_bible::book_write (webserver_request, std::string(), bible, book)) {
     return translate ("No write access");
   }
 
   
-  string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_editor_stylesheet (bible);
  
   
-  string verse_usfm = editone_logic_html_to_usfm (stylesheet, html);
+  std::string verse_usfm = editone_logic_html_to_usfm (stylesheet, html);
 
   
   // Collect some data about the changes for this user.
-  string username = request->session_logic()->currentUser ();
+  const std::string& username = webserver_request.session_logic ()->get_username ();
 #ifdef HAVE_CLOUD
-  int oldID = request->database_bibles()->getChapterId (bible, book, chapter);
+  int oldID = database::bibles::get_chapter_id (bible, book, chapter);
 #endif
-  string old_chapter_usfm = request->database_bibles()->getChapter (bible, book, chapter);
+  std::string old_chapter_usfm = database::bibles::get_chapter (bible, book, chapter);
 
   
   // If the most recent save operation on this chapter
@@ -130,36 +125,35 @@ string editone2_save (void * webserver_request)
   // it's worth to check on this.
   // Because the user's editor may not yet have loaded this updated Bible text.
   // https://github.com/bibledit/cloud/issues/340
-  string loaded_usfm = getLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
+  std::string loaded_usfm = getLoadedUsfm2 (webserver_request, bible, book, chapter, unique_id);
   if (loaded_usfm != old_chapter_usfm) {
-    bible_logic_recent_save_email (bible, book, chapter, username, loaded_usfm, old_chapter_usfm);
+    bible_logic::recent_save_email (bible, book, chapter, username, loaded_usfm, old_chapter_usfm);
   }
 
   
   // Safely store the verse.
-  string explanation;
-  string message = usfm_safely_store_verse (request, bible, book, chapter, verse, verse_usfm, explanation, true);
-  bible_logic_unsafe_save_mail (message, explanation, username, verse_usfm, book, chapter);
+  std::string explanation;
+  std::string message = filter::usfm::safely_store_verse (webserver_request, bible, book, chapter, verse, verse_usfm, explanation, true);
+  bible_logic::unsafe_save_mail (message, explanation, username, verse_usfm, book, chapter);
   // If storing the verse worked out well, there's no message to display.
   if (message.empty ()) {
     // Get the chapter text now, that is, after the save operation completed.
-    string new_chapter_usfm = request->database_bibles()->getChapter (bible, book, chapter);
+    std::string new_chapter_usfm = database::bibles::get_chapter (bible, book, chapter);
     // Check whether the text on disk was changed while the user worked with the older copy.
     if (!loaded_usfm.empty () && (loaded_usfm != old_chapter_usfm)) {
       // Do a merge for better editing reliability.
-      vector <Merge_Conflict> conflicts;
+      std::vector <Merge_Conflict> conflicts;
       // Prioritize the USFM already in the chapter.
       new_chapter_usfm = filter_merge_run (loaded_usfm, new_chapter_usfm, old_chapter_usfm, true, conflicts);
-      request->database_bibles()->storeChapter (bible, book, chapter, new_chapter_usfm);
+      database::bibles::store_chapter (bible, book, chapter, new_chapter_usfm);
       Database_Logs::log (translate ("Merging chapter."));
     }
 #ifdef HAVE_CLOUD
     // The Cloud stores details of the user's changes.
-    int newID = request->database_bibles()->getChapterId (bible, book, chapter);
-    Database_Modifications database_modifications;
-    database_modifications.recordUserSave (username, bible, book, chapter, oldID, old_chapter_usfm, newID, new_chapter_usfm);
+    int newID = database::bibles::get_chapter_id (bible, book, chapter);
+    database::modifications::recordUserSave (username, bible, book, chapter, oldID, old_chapter_usfm, newID, new_chapter_usfm);
     if (sendreceive_git_repository_linked (bible)) {
-      Database_Git::store_chapter (username, bible, book, chapter, old_chapter_usfm, new_chapter_usfm);
+      database::git::store_chapter (username, bible, book, chapter, old_chapter_usfm, new_chapter_usfm);
     }
     rss_logic_schedule_update (username, bible, book, chapter, old_chapter_usfm, new_chapter_usfm);
 #endif
