@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,28 +17,23 @@
  */
 
 
-#ifndef INCLUDED_EDITOR_STYLES_H
-#define INCLUDED_EDITOR_STYLES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
 class Editor_Styles
 {
 public:
-  static string getRecentlyUsed (void * webserver_request);
-  static string getAll (void * webserver_request);
-  static void recordUsage (void * webserver_request, string style);
-  static string getAction (void * webserver_request, string style);
+  static std::string getRecentlyUsed (Webserver_Request& webserver_request);
+  static std::string getAll (Webserver_Request& webserver_request);
+  static void recordUsage (Webserver_Request& webserver_request, const std::string& style);
+  static std::string getAction (Webserver_Request& webserver_request, const std::string& style);
 private:
-  static string unknown ();
-  static string paragraph ();
-  static string character ();
-  static string mono ();
-  static string note ();
+  static std::string unknown ();
+  static std::string paragraph ();
+  static std::string character ();
+  static std::string mono ();
+  static std::string note ();
 };
-
-
-#endif
-
