@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <windows.h>
 #endif
 #include <config/globals.h>
-using namespace std;
 
 // Fix for architecture hurd-i386 that does not define MAXPATHLEN.
 #ifndef MAXPATHLEN
@@ -40,27 +39,19 @@ using namespace std;
 #endif
 
 
-// Declarations.
-void sigint_handler ([[maybe_unused]] int s);
-string backtrace_path ();
-[[ noreturn ]]
-void sigsegv_handler ([[maybe_unused]] int sig);
-
-
-void sigint_handler ([[maybe_unused]] int s)
+static void sigint_handler ([[maybe_unused]] int s)
 {
   // When pressing Ctrl-C, the system outputs a "^C".
   // It is cleaner to write a new line after that.
-  cout << endl;
+  std::cout << std::endl;
   // Initiate server(s) shutdown.
   bibledit_stop_library ();
 }
 
 
-string backtrace_path ()
+static std::string backtrace_path ()
 {
-  string path = filter_url_create_root_path ({filter_url_temp_dir (), "backtrace.txt"});
-  return path;
+  return filter_url_create_root_path ({filter_url_temp_dir (), "backtrace.txt"});
 }
 
 
@@ -68,16 +59,14 @@ string backtrace_path ()
 // http://stackoverflow.com/questions/77005/how-to-generate-a-stacktrace-when-my-gcc-c-app-crashes
 // To add linker flag -rdynamic is essential.
 [[ noreturn ]]
-void sigsegv_handler ([[maybe_unused]] int sig)
+static void sigsegv_handler ([[maybe_unused]] int sig)
 {
   // Information.
-  cout << "Segmentation fault, writing backtrace to " << backtrace_path () << endl;
-
-  void *array[20];
-  int size;
+  std::cout << "Segmentation fault, writing backtrace to " << backtrace_path () << std::endl;
   
   // Get void*'s for all entries on the stack
-  size = backtrace (array, 20);
+  void *array[20];
+  int size = backtrace (array, 20);
 
   // Write entries to file (to be logged next time bibledit starts).
   int fd = open (backtrace_path ().c_str (), O_WRONLY|O_CREAT, 0666);
@@ -91,12 +80,12 @@ void sigsegv_handler ([[maybe_unused]] int sig)
 
 #ifdef HAVE_WINDOWS
 void my_invalid_parameter_handler(const wchar_t* expression, const wchar_t* function, const wchar_t* file,	unsigned int line, uintptr_t pReserved) {
-  wstring wexpression(expression);
-  string sexpression(wexpression.begin(), wexpression.end());
-  wstring wfunction(function);
-  string sfunction(wfunction.begin(), wfunction.end());
-  wstring wfile (file);
-  string sfile(wfile.begin(), wfile.end());
+  std::wstring wexpression(expression);
+  std::string sexpression(wexpression.begin(), wexpression.end());
+  std::wstring wfunction(function);
+  std::string sfunction(wfunction.begin(), wfunction.end());
+  std::wstring wfile (file);
+  std::string sfile(wfile.begin(), wfile.end());
   Database_Logs::log ("Invalid parameter detected in function " + sfunction + " in file " + sfile + " line " + filter::strings::convert_to_string ((size_t)line) + " expression " + sexpression + ".");
 }
 #endif
@@ -123,13 +112,13 @@ int main ([[maybe_unused]] int argc, [[maybe_unused]] char **argv)
 
   
   // Get the executable path and derive the document root from it.
-  string webroot;
+  std::string webroot {};
 #ifndef HAVE_WINDOWS
   {
     // The following works on Linux but not on macOS:
     char *linkname = static_cast<char *> (malloc (256));
     memset (linkname, 0, 256); // valgrind uninitialized value(s)
-    [[maybe_unused]] ssize_t result = readlink ("/proc/self/exe", linkname, 256);
+    [[maybe_unused]] auto result = readlink ("/proc/self/exe", linkname, 256);
     webroot = filter_url_dirname (linkname);
     free (linkname);
   }
@@ -137,11 +126,9 @@ int main ([[maybe_unused]] int argc, [[maybe_unused]] char **argv)
 #ifdef HAVE_LIBPROC
   {
     // The following works on Linux and on macOS:
-    int ret;
-    pid_t pid;
+    pid_t pid = getpid ();
     char pathbuf [2048];
-    pid = getpid ();
-    ret = proc_pidpath (pid, pathbuf, sizeof (pathbuf));
+    int ret = proc_pidpath (pid, pathbuf, sizeof (pathbuf));
     if (ret > 0 ) {
       webroot = filter_url_dirname (pathbuf);
     }
@@ -167,10 +154,10 @@ int main ([[maybe_unused]] int argc, [[maybe_unused]] char **argv)
   // The following is for the Cloud configuration only:
   {
     // Get home folder and working directory.
-    string home_folder;
+    std::string home_folder;
     const char * home_env_ptr = getenv ("HOME");
     if (home_env_ptr) home_folder = home_env_ptr;
-    string workingdirectory;
+    std::string workingdirectory;
     char cwd [MAXPATHLEN];
     if (getcwd(cwd, sizeof(cwd)) != nullptr) workingdirectory = cwd;
     // If the web root folder, derived from the binary, is the same as the current directory,
@@ -200,20 +187,20 @@ int main ([[maybe_unused]] int argc, [[maybe_unused]] char **argv)
   // Start the Bibledit library.
   bibledit_start_library ();
   bibledit_log ("The server started");
-  cout << "Listening on http://localhost:" << config::logic::http_network_port () << endl;
-  cout << "Press Ctrl-C to quit" << endl;
+  std::cout << "Listening on http://localhost:" << config::logic::http_network_port () << std::endl;
+  std::cout << "Press Ctrl-C to quit" << std::endl;
 
   
   // Log possible backtrace from a previous crash.
-  string backtrace = filter_url_file_get_contents (backtrace_path ());
+  std::string backtrace = filter_url_file_get_contents (backtrace_path ());
   filter_url_unlink (backtrace_path ());
   if (!backtrace.empty ()) {
     Database_Logs::log ("Backtrace of the last segmentation fault:");
-    vector <string> lines = filter::strings::explode (backtrace, '\n');
+    std::vector <std::string> lines = filter::strings::explode (backtrace, '\n');
     for (auto & line : lines) {
       Database_Logs::log (line);
       // Set a flag if the backtrace appears to be caused while sending email.
-      if (line.find ("email_send") != string::npos) config_globals_has_crashed_while_mailing = true;
+      if (line.find ("email_send") != std::string::npos) config_globals_has_crashed_while_mailing = true;
     }
   }
 
