@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,23 +29,21 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #pragma GCC diagnostic ignored "-Wuseless-cast"
 #include <jsonxx/jsonxx.h>
 #pragma GCC diagnostic pop
-using namespace std;
-using namespace jsonxx;
 
 
 namespace filter::google {
 
 
-tuple <string, string> get_json_key_value_error ()
+std::tuple <std::string, std::string> get_json_key_value_error ()
 {
-  string path = config::logic::google_translate_json_key_path ();
+  std::string path = config::logic::google_translate_json_key_path ();
 
   if (!file_or_dir_exists (path)) {
-    return { string(), "Cannot find the JSON key to access Google Translate. Looking for this file: " + path };
+    return { std::string(), "Cannot find the JSON key to access Google Translate. Looking for this file: " + path };
   }
   
-  string error;
-  string value = filter_url_file_get_contents (path);
+  std::string error;
+  std::string value = filter_url_file_get_contents (path);
   if (value.empty()) error = "The key at " + path + " is empty";
 
   return { value, error };
@@ -55,31 +53,31 @@ tuple <string, string> get_json_key_value_error ()
 // This runs $ gcloud auth activate-service-account --key-file=key.json.
 // It returns whether activation was successful,
 // plus the resulting output of the command.
-tuple <bool, string> activate_service_account ()
+std::tuple <bool, std::string> activate_service_account ()
 {
-  stringstream command;
+  std::stringstream command;
   command << "gcloud auth activate-service-account --quiet --key-file=";
-  command << quoted(config::logic::google_translate_json_key_path ());
-  string out_err;
+  command << std::quoted(config::logic::google_translate_json_key_path ());
+  std::string out_err;
   int result = filter_shell_run (command.str(), out_err);
   return { (result == 0), out_err };
 }
 
 
-string google_access_token {};
+std::string google_access_token {};
 
 // This runs $ gcloud auth application-default print-access-token.
 // It returns whether the command was successful,
 // plus the resulting output of the command.
-tuple <bool, string> print_store_access_token ()
+std::tuple <bool, std::string> print_store_access_token ()
 {
   // Set the path to the JSON key in the environment for gcloud to use.
 #ifdef HAVE_CLOUD
   setenv("GOOGLE_APPLICATION_CREDENTIALS", config::logic::google_translate_json_key_path ().c_str(), 1);
 #endif
   // Print the access token.
-  string command {"gcloud auth application-default print-access-token"};
-  string out_err;
+  std::string command {"gcloud auth application-default print-access-token"};
+  std::string out_err;
   int result = filter_shell_run (command.c_str(), out_err);
   // Check on success.
   bool success = (result == 0);
@@ -111,31 +109,31 @@ void refresh_access_token ()
 // Pass the text to be translated.
 // Pass the source language code and the target language code.
 // It returns whether the call was successful, plus the translated text, plus the error
-tuple <bool, string, string> translate (const string text, const char * source, const char * target)
+std::tuple <bool, std::string, std::string> translate (const std::string text, const char * source, const char * target)
 {
   // From the shell, run these two commands to translate a string.
   // $ export GOOGLE_APPLICATION_CREDENTIALS=`pwd`"/googletranslate.json"
   // $ curl -s -X POST -H "Content-Type: application/json" -H "Authorization: Bearer "$(gcloud auth application-default print-access-token) --data "{ 'q': 'The quick brown fox jumps over the lazy dog', 'source': 'en', 'target': 'fr', 'format': 'text' }" "https://translation.googleapis.com/language/translate/v2"
 
   // The URL of the translation REST API.
-  const string url { "https://translation.googleapis.com/language/translate/v2" };
+  const std::string url { "https://translation.googleapis.com/language/translate/v2" };
 
   // Create the JSON data to post.
-  Object translation_data;
+  jsonxx::Object translation_data;
   translation_data << "q" << text;
-  translation_data << "source" << string (source);
-  translation_data << "target" << string (target);
+  translation_data << "source" << std::string (source);
+  translation_data << "target" << std::string (target);
   translation_data << "format" << "text";
-  string postdata = translation_data.json ();
+  std::string postdata = translation_data.json ();
   
-  string error;
+  std::string error;
   bool burst { false };
   bool check_certificate { false };
-  const vector <pair <string, string> > headers {
+  const std::vector <std::pair <std::string, std::string> > headers {
     { "Content-Type", "application/json" },
     { "Authorization", "Bearer " + google_access_token }
   };
-  string translation = filter_url_http_post (url, postdata, {}, error, burst, check_certificate, headers);
+  std::string translation = filter_url_http_post (url, postdata, {}, error, burst, check_certificate, headers);
   bool success { error.empty() };
 
   // Parse the translation JSON.
@@ -151,13 +149,13 @@ tuple <bool, string, string> translate (const string text, const char * source,
   // }
   if (error.empty()) {
     try {
-      Object json_object;
+      jsonxx::Object json_object;
       json_object.parse (translation);
-      Object data = json_object.get<Object> ("data");
-      Array translations = data.get<Array> ("translations");
-      Object translated = translations.get<Object>(0);
-      translation = translated.get<String> ("translatedText");
-    } catch (const exception & exception) {
+      jsonxx::Object data = json_object.get<jsonxx::Object> ("data");
+      jsonxx::Array translations = data.get<jsonxx::Array> ("translations");
+      jsonxx::Object translated = translations.get<jsonxx::Object>(0);
+      translation = translated.get<jsonxx::String> ("translatedText");
+    } catch (const std::exception & exception) {
       error = exception.what();
       error.append (" - ");
       error.append(translation);
@@ -178,7 +176,7 @@ tuple <bool, string, string> translate (const string text, const char * source,
 // This asks the Google Translate API for the list of supported languages.
 // It returns a container with a pair of <language code, language name>.
 // The language name is given in the $target language.
-vector <pair <string, string> > get_languages (const string & target)
+std::vector <std::pair <std::string, std::string> > get_languages (const std::string& target)
 {
 
   // From the shell, run these two commands to translate a string.
@@ -186,21 +184,21 @@ vector <pair <string, string> > get_languages (const string & target)
   // $ curl -s -X POST -H "Content-Type: application/json; charset=utf-8" -H "Authorization: Bearer "$(gcloud auth application-default print-access-token) --data "{ 'target': 'en' }" "https://translation.googleapis.com/language/translate/v2/languages"
   
   // The URL of the translation REST API.
-  const string url { "https://translation.googleapis.com/language/translate/v2/languages" };
+  const std::string url { "https://translation.googleapis.com/language/translate/v2/languages" };
   
   // Create the JSON data to post.
-  Object request_data;
+  jsonxx::Object request_data;
   request_data << "target" << target;
-  string postdata = request_data.json ();
+  std::string postdata = request_data.json ();
   
-  string error;
+  std::string error;
   bool burst { false };
   bool check_certificate { false };
-  const vector <pair <string, string> > headers {
+  const std::vector <std::pair <std::string, std::string> > headers {
     { "Content-Type", "application/json; charset=utf-8" },
     { "Authorization", "Bearer " + google_access_token }
   };
-  string result_json = filter_url_http_post (url, postdata, {}, error, burst, check_certificate, headers);
+  std::string result_json = filter_url_http_post (url, postdata, {}, error, burst, check_certificate, headers);
   
   // Parse the resulting JSON.
   // Example:
@@ -222,20 +220,20 @@ vector <pair <string, string> > get_languages (const string & target)
   //     ]
   //   }
   // }
-  vector <pair <string, string> > language_codes_names;
+  std::vector <std::pair <std::string, std::string> > language_codes_names;
   if (error.empty()) {
     try {
-      Object json_object;
+      jsonxx::Object json_object;
       json_object.parse (result_json);
-      Object data = json_object.get<Object> ("data");
-      Array languages = data.get<Array> ("languages");
+      jsonxx::Object data = json_object.get<jsonxx::Object> ("data");
+      jsonxx::Array languages = data.get<jsonxx::Array> ("languages");
       for (size_t i = 0; i < languages.size(); i++) {
-        Object language_name = languages.get<Object>(static_cast<unsigned>(i));
-        string language = language_name.get<String>("language");
-        string name = language_name.get<String>("name");
+        jsonxx::Object language_name = languages.get<jsonxx::Object>(static_cast<unsigned>(i));
+        std::string language = language_name.get<jsonxx::String>("language");
+        std::string name = language_name.get<jsonxx::String>("name");
         language_codes_names.push_back({language, name});
       }
-    } catch (const exception & exception) {
+    } catch (const std::exception & exception) {
       error = exception.what();
       error.append (" - ");
       error.append(result_json);
