@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,4 +21,4 @@
 
 #include <config/libraries.h>
 
-string filter_html_android_brs ();
+std::string filter_html_android_brs ();
