@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,17 +17,8 @@
  */
 
 
-#ifndef INCLUDED_FILTER_MD5_H
-#define INCLUDED_FILTER_MD5_H
-
+#pragma once
 
 #include <config/libraries.h>
 
-
-string md5 (const string str);
-
-
-#endif
-
-
-
+std::string md5 (const std::string str);
