@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,25 +22,24 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <database/logs.h>
 #include <locale/translate.h>
-using namespace std;
 
 
 // Sets a variable (key and value) for the html template.
-void Flate::set_variable (string key, string value)
+void Flate::set_variable (std::string key, std::string value)
 {
   variables [key] = value;
 }
 
 
 // Enable a zone in the html template.
-void Flate::enable_zone (string zone)
+void Flate::enable_zone (std::string zone)
 {
   zones [zone] = true;
 }
 
 
 // Add $value-s for one iteration to iterator $key.
-void Flate::add_iteration (string key, map <string, string> value)
+void Flate::add_iteration (std::string key, std::map <std::string, std::string> value)
 {
   // The $key is the name for the iteration,
   // where to add $value, which is a map of keys and values.
@@ -49,9 +48,9 @@ void Flate::add_iteration (string key, map <string, string> value)
 
 
 // Renders the html template.
-string Flate::render (string html)
+std::string Flate::render (std::string html)
 {
-  string rendering;
+  std::string rendering;
   try {
     if (file_or_dir_exists (html)) {
       rendering = filter_url_file_get_contents (html);
@@ -64,7 +63,7 @@ string Flate::render (string html)
     Database_Logs::log ("Failure to process template " + html);
   }
   // Remove empty lines.
-  vector <string> lines = filter::strings::explode (rendering, '\n');
+  std::vector <std::string> lines = filter::strings::explode (rendering, '\n');
   rendering.clear ();
   for (auto & line : lines) {
     line = filter::strings::trim (line);
@@ -77,41 +76,41 @@ string Flate::render (string html)
 }
 
 
-void Flate::process_iterations (string & rendering)
+void Flate::process_iterations (std::string & rendering)
 {
   // Limit iteration count.
   int iteration_count = 0;
   // Start processing iterations by locating the first one.
-  string beginiteration ("<!-- #BEGINITERATION");
+  std::string beginiteration ("<!-- #BEGINITERATION");
   size_t position = rendering.find (beginiteration);
   // Iterate through the rendering till all have been dealt with.
-  while ((position != string::npos) && (iteration_count < 100)) {
+  while ((position != std::string::npos) && (iteration_count < 100)) {
     iteration_count++;
     // Position where the opening tag ends.
     size_t pos = rendering.find ("-->", position);
-    string iteration_start_line = rendering.substr (position, pos - position + 3);
+    std::string iteration_start_line = rendering.substr (position, pos - position + 3);
     // Remove the opening tag for the current iteration.
     rendering.erase (position, iteration_start_line.length ());
     // Name for the current iteration.
-    string name = iteration_start_line.substr (21, iteration_start_line.length () - 21 - 4);
+    std::string name = iteration_start_line.substr (21, iteration_start_line.length () - 21 - 4);
     // Assemble the ending line for the current iteration.
-    string iterationendline = "<!-- #ENDITERATION " + name + " -->";
+    std::string iterationendline = "<!-- #ENDITERATION " + name + " -->";
     // Locate the ending position.
     size_t iterationendposition = rendering.find (iterationendline);
     // Process if it exists.
-    if (iterationendposition != string::npos) {
+    if (iterationendposition != std::string::npos) {
       // Take the ending line out.
       rendering.erase (iterationendposition, iterationendline.length ());
       // Get and remove the inner contents of this iteration.
-      string iterating_fragment = rendering.substr (position, iterationendposition - position);
+      std::string iterating_fragment = rendering.substr (position, iterationendposition - position);
       rendering.erase (position, iterationendposition - position);
       // The fragment to insert after ready iterating.
-      string iterated_fragment;
+      std::string iterated_fragment;
       // Go through the container for the name of the current iteration.
-      vector < map <string, string> > named_iterations = iterations [name];
+      std::vector < std::map <std::string, std::string> > named_iterations = iterations [name];
       for (auto & named_iteration : named_iterations) {
         // Process one iteration.
-        string fragment (iterating_fragment);
+        std::string fragment (iterating_fragment);
         for (auto & element : named_iteration) {
           fragment = filter::strings::replace ("##" + element.first + "##", element.second, fragment);
         }
@@ -129,29 +128,29 @@ void Flate::process_iterations (string & rendering)
 }
 
 
-void Flate::process_zones (string& rendering)
+void Flate::process_zones (std::string& rendering)
 {
   // Limit zone iterations.
   int zone_iteration_count = 0;
   // Start processing zones by locating the first one.
-  string beginzone ("<!-- #BEGINZONE");
+  std::string beginzone ("<!-- #BEGINZONE");
   size_t position = rendering.find (beginzone);
   // Iterate through the file contents till all zones have been dealt with.
-  while ((position != string::npos) && (zone_iteration_count < 1000)) {
+  while ((position != std::string::npos) && (zone_iteration_count < 1000)) {
     zone_iteration_count++;
     // Position where the starting zone ends.
     size_t pos = rendering.find ("-->", position);
-    string zonestartline = rendering.substr (position, pos - position + 3);
+    std::string zonestartline = rendering.substr (position, pos - position + 3);
     // Remove the opening tag for the current zone.
     rendering.erase (position, zonestartline.length ());
     // Name for the current zone.
-    string name = zonestartline.substr (16, zonestartline.length () - 16 - 4);
+    std::string name = zonestartline.substr (16, zonestartline.length () - 16 - 4);
     // Assemble the ending line for the current zone.
-    string zoneendline = "<!-- #ENDZONE " + name + " -->";
+    std::string zoneendline = "<!-- #ENDZONE " + name + " -->";
     // Locate the ending position.
     size_t zoneendposition = rendering.find (zoneendline);
     // Process if it exists.
-    if (zoneendposition != string::npos) {
+    if (zoneendposition != std::string::npos) {
       // Take the ending line out.
       rendering.erase (zoneendposition, zoneendline.length ());
       // If the zone has not been enabled, remove all its contents within.
@@ -165,14 +164,14 @@ void Flate::process_zones (string& rendering)
 }
 
 
-void Flate::process_variables (string& rendering)
+void Flate::process_variables (std::string& rendering)
 {
   // Limit variable iterations.
   int variable_iteration_count = 0;
   // Start processing variables by locating the first one.
   size_t position = rendering.find ("##");
   // Iterate through the contents till all variables have been dealt with.
-  while ((position != string::npos) && (variable_iteration_count < 1000)) {
+  while ((position != std::string::npos) && (variable_iteration_count < 1000)) {
     variable_iteration_count++;
     bool correct = true;
     // Check that this is a correct position: It should not have hashes nearby.
@@ -184,11 +183,11 @@ void Flate::process_variables (string& rendering)
     }
     // Position where the variable ends.
     size_t pos = rendering.find ("##", position + 1);
-    if (pos == string::npos) pos = position + 4;
+    if (pos == std::string::npos) pos = position + 4;
     // Name for the variable zone.
-    string name = rendering.substr (position + 2, pos - position - 2);
+    std::string name = rendering.substr (position + 2, pos - position - 2);
     // No new line in the variable name.
-    if (correct) if (name.find ("\n") != string::npos) correct = false;
+    if (correct) if (name.find ("\n") != std::string::npos) correct = false;
     if (correct) {
       // Take the variable out.
       rendering.erase (position, name.length () + 4);
@@ -201,29 +200,29 @@ void Flate::process_variables (string& rendering)
 }
 
 
-void Flate::process_translate (string& rendering)
+void Flate::process_translate (std::string& rendering)
 {
   // Clean up the "translate" (gettext) calls.
   rendering = filter::strings::replace ("translate (", "translate(", rendering);
   // Gettext markup.
-  string gettextopen = R"(translate(")";
-  string gettextclose = R"("))";
+  std::string gettextopen = R"(translate(")";
+  std::string gettextclose = R"("))";
   // Limit gettext iterations.
   int iteration_counter { 0 };
   // Start processing variables by locating the first one.
   size_t position = rendering.find (gettextopen);
   // Iterate through the contents till all gettext calls have been dealt with.
-  while ((position != string::npos) && (iteration_counter < 1000)) {
+  while ((position != std::string::npos) && (iteration_counter < 1000)) {
     iteration_counter++;
     // Remove the gettext opener.
     rendering.erase (position, gettextopen.length());
     // Position where the gettext call ends.
     size_t pos = rendering.find (gettextclose, position);
-    if (pos != string::npos) {
+    if (pos != std::string::npos) {
       // Take the gettext closer out.
       rendering.erase (pos, gettextclose.length());
       // The English string.
-      string english = rendering.substr (position, pos - position);
+      std::string english = rendering.substr (position, pos - position);
       // Take the English out.
       rendering.erase (position, pos - position);
       // Insert the localization.
