@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -87,9 +87,9 @@ void erase (const std::string& font)
 // Ahd when the client sets its own font, this font will be taken instead.
 std::string get_text_font (const std::string& bible)
 {
-  std::string font = Database_Config_Bible::getTextFont (bible);
+  std::string font = database::config::bible::get_text_font (bible);
 #ifdef HAVE_CLIENT
-  const std::string client_font = Database_Config_Bible::getTextFontClient (bible);
+  const std::string client_font = database::config::bible::get_text_font_client (bible);
   if (!client_font.empty ()) {
     font = client_font;
   }
