@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,13 @@
 
 #include <config/libraries.h>
 
-class Fonts_Logic
-{
-public:
-  static std::vector <std::string> getFonts ();
-  static bool font_exists (std::string font);
-  static std::string get_font_path (std::string font);
-  static void erase (std::string font);
-  static std::string get_text_font (std::string bible);
-  static bool is_font (std::string suffix);
-private:
-  static std::string folder ();
-};
+namespace fonts::logic {
+
+std::vector <std::string> get_fonts ();
+bool font_exists (const std::string& font);
+std::string get_font_path (const std::string& font);
+void erase (const std::string& font);
+std::string get_text_font (const std::string& bible);
+bool is_font (const std::string& suffix);
+
+} // namespace
