@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,6 @@
 #include <filter/shell.h>
 #include <filter/roles.h>
 #include <database/logs.h>
-using namespace std;
 
 
 /*
@@ -52,29 +51,29 @@ using namespace std;
 
 // These global variables contain the settings for the OpenLDAP server
 // to query for user credentials.
-string ldap_logic_uri {};
-string ldap_logic_binddn {};
-string ldap_logic_basedn {};
-string ldap_logic_scope {};
-string ldap_logic_filter {};
-string ldap_logic_role {};
+std::string ldap_logic_uri {};
+std::string ldap_logic_binddn {};
+std::string ldap_logic_basedn {};
+std::string ldap_logic_scope {};
+std::string ldap_logic_filter {};
+std::string ldap_logic_role {};
 
 
 // Initialize the configuration for accessing an OpenLDAP server.
 void ldap_logic_initialize ()
 {
   // Check if the OpenLDAP configuration file exists.
-  const string path = filter_url_create_root_path ({config::logic::config_folder (), "ldap.conf"});
+  const std::string path = filter_url_create_root_path ({config::logic::config_folder (), "ldap.conf"});
   if (file_or_dir_exists (path)) {
     // Parse the configuration file.
-    const string contents = filter_url_file_get_contents (path);
-    const vector <string> lines = filter::strings::explode (contents, '\n');
+    const std::string contents = filter_url_file_get_contents (path);
+    const std::vector <std::string> lines = filter::strings::explode (contents, '\n');
     for (auto line : lines) {
       line = filter::strings::trim (line);
       if (line.empty ()) continue;
       if (line.substr (0, 1) == "#") continue;
       size_t pos = line.find ("=");
-      const string key = filter::strings::trim (line.substr (0, pos));
+      const std::string key = filter::strings::trim (line.substr (0, pos));
       line.erase (0, ++pos);
       line = filter::strings::trim (line);
       if (key == "uri"   ) ldap_logic_uri    = line;
@@ -140,7 +139,7 @@ bool ldap_logic_is_on (bool log)
 // Parameter $mail returns the email address.
 // Parameter $role returns the user's role.
 // If the query was done successfully, the function returns true.
-bool ldap_logic_fetch (const string& user, const string& password, bool& access, string& email, int& role, bool log)
+bool ldap_logic_fetch (const std::string& user, const std::string& password, bool& access, std::string& email, int& role, bool log)
 {
   // Initialize result values for the caller.
   access = false;
@@ -148,11 +147,11 @@ bool ldap_logic_fetch (const string& user, const string& password, bool& access,
   role = Filter_Roles::guest ();
   
   // Insert the user name where appropriate.
-  const string binddn = filter::strings::replace ("[user]", user, ldap_logic_binddn);
-  const string filter = filter::strings::replace ("[user]", user, ldap_logic_filter);
+  const std::string binddn = filter::strings::replace ("[user]", user, ldap_logic_binddn);
+  const std::string filter = filter::strings::replace ("[user]", user, ldap_logic_filter);
   
   // Query the LDAP server.
-  string output {};
+  std::string output {};
   const int result = filter_shell_vfork (output, "", "ldapsearch",
                                          "-H", ldap_logic_uri.c_str (),
                                          "-D", binddn.c_str (),
@@ -163,7 +162,7 @@ bool ldap_logic_fetch (const string& user, const string& password, bool& access,
   
   // Logging.
   if (log) {
-    const string command = "ldapsearch -H " + ldap_logic_uri + " -D " + binddn + " -w " + password + " -b " + ldap_logic_basedn + " -s " + ldap_logic_scope + " " + filter;
+    const std::string command = "ldapsearch -H " + ldap_logic_uri + " -D " + binddn + " -w " + password + " -b " + ldap_logic_basedn + " -s " + ldap_logic_scope + " " + filter;
     Database_Logs::log ("LDAP query\n" + command + "\n" + output, Filter_Roles::admin ());
   }
   
@@ -175,15 +174,15 @@ bool ldap_logic_fetch (const string& user, const string& password, bool& access,
   // Parse server response.
   if (result == 0) {
     access = true;
-    const vector <string> lines = filter::strings::explode (output, '\n');
+    const std::vector <std::string> lines = filter::strings::explode (output, '\n');
     for (const auto& line : lines) {
       if (line.find ("mail:") == 0) {
         email = filter::strings::trim (line.substr (5));
       }
       if (line.find (ldap_logic_role + ":") == 0) {
-        const string fragment = filter::strings::unicode_string_casefold (filter::strings::trim (line.substr (3)));
+        const std::string fragment = filter::strings::unicode_string_casefold (filter::strings::trim (line.substr (3)));
         for (int r = Filter_Roles::lowest (); r <= Filter_Roles::highest (); r++) {
-          if (fragment.find (filter::strings::unicode_string_casefold (Filter_Roles::english (r))) != string::npos) {
+          if (fragment.find (filter::strings::unicode_string_casefold (Filter_Roles::english (r))) != std::string::npos) {
             role = r;
           }
         }
