@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
-string notes_assign_1_url ();
-bool notes_assign_1_acl (void * webserver_request);
-string notes_assign_1 (void * webserver_request);
+class Webserver_Request;
+
+std::string notes_assign_1_url ();
+bool notes_assign_1_acl (Webserver_Request& webserver_request);
+std::string notes_assign_1 (Webserver_Request& webserver_request);
