@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,39 +32,37 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
-using namespace std;
 
 
-string notes_bible_n_url ()
+std::string notes_bible_n_url ()
 {
   return "notes/bb-n";
 }
 
 
-bool notes_bible_n_acl (void * webserver_request)
+bool notes_bible_n_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ());
 }
 
 
-string notes_bible_n (void * webserver_request)
+std::string notes_bible_n (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
-  Notes_Logic notes_logic = Notes_Logic (webserver_request);
+  Notes_Logic notes_logic (webserver_request);
 
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Bibles"), request);
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Bibles"), webserver_request);
   page += header.run ();
   Assets_View view;
   
   
-  stringstream bibleblock;
-  vector <string> bibles = access_bible::bibles (webserver_request);
+  std::stringstream bibleblock;
+  std::vector <std::string> bibles = access_bible::bibles (webserver_request);
   bibles.push_back (notes_logic.generalBibleName ());
-  for (auto & bible : bibles) {
-    bibleblock << "<li><a href=" << quoted("bulk?bible=" + bible) << ">" << bible << "</a></li>" << endl;
+  for (const auto & bible : bibles) {
+    bibleblock << "<li><a href=" << std::quoted("bulk?bible=" + bible) << ">" << bible << "</a></li>" << std::endl;
   }
   view.set_variable ("bibleblock", bibleblock.str());
   
