@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,16 +32,15 @@
 #include <ipc/focus.h>
 #include <navigation/passage.h>
 #include <notes/actions.h>
-using namespace std;
 
 
-string notes_status_1_url ()
+std::string notes_status_1_url ()
 {
   return "notes/status-1";
 }
 
 
-bool notes_status_1_acl (void * webserver_request)
+bool notes_status_1_acl (Webserver_Request& webserver_request)
 {
   // Translator should be able to set the status of a note.
   // https://github.com/bibledit/cloud/issues/243
@@ -49,36 +48,35 @@ bool notes_status_1_acl (void * webserver_request)
 }
 
 
-string notes_status_1 (void * webserver_request)
+std::string notes_status_1 (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
   Database_Notes database_notes (webserver_request);
-  Notes_Logic notes_logic = Notes_Logic (webserver_request);
+  Notes_Logic notes_logic (webserver_request);
   
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Note status"), request);
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Note status"), webserver_request);
   page += header.run ();
   Assets_View view;
-  string success, error;
+  std::string success, error;
   
   
-  int id = filter::strings::convert_to_int (request->query ["id"]);
-  view.set_variable ("id", filter::strings::convert_to_string (id));
+  int id = filter::strings::convert_to_int (webserver_request.query ["id"]);
+  view.set_variable ("id", std::to_string (id));
   
   
-  if (request->query.count ("status")) {
-    string status = request->query["status"];
+  if (webserver_request.query.count ("status")) {
+    std::string status = webserver_request.query["status"];
     notes_logic.setStatus (id, status);
-    redirect_browser (request, notes_actions_url () + "?id=" + filter::strings::convert_to_string (id));
-    return "";
+    redirect_browser (webserver_request, notes_actions_url () + "?id=" + std::to_string (id));
+    return std::string();
   }
   
   
-  stringstream statusblock;
-  vector <Database_Notes_Text> statuses = database_notes.get_possible_statuses ();
-  for (auto & status : statuses) {
-    statusblock << "<li><a href=" << quoted ("status-1?id=" + filter::strings::convert_to_string (id) + "&status=" + status.raw) << ">" << status.localized + "</a></li>" << endl;
+  std::stringstream statusblock;
+  const std::vector <Database_Notes_Text> statuses = database_notes.get_possible_statuses ();
+  for (const auto& status : statuses) {
+    statusblock << "<li><a href=" << std::quoted ("status-1?id=" + std::to_string (id) + "&status=" + status.raw) << ">" << status.localized + "</a></li>" << std::endl;
   }
   view.set_variable ("statusblock", statusblock.str());
   
