@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_PARATEXT_INDEX_H
-#define INCLUDED_PARATEXT_INDEX_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string paratext_index_url ();
-bool paratext_index_acl (void * webserver_request);
-string paratext_index (void * webserver_request);
-
-
-#endif
+std::string paratext_index_url ();
+bool paratext_index_acl (Webserver_Request& webserver_request);
+std::string paratext_index (Webserver_Request& webserver_request);
