@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -23,40 +23,38 @@
 #include <webserver/request.h>
 #include <ipc/focus.h>
 #include <access/bible.h>
-using namespace std;
 
 
-string read_verse_url ()
+std::string read_verse_url ()
 {
   return "read/verse";
 }
 
 
-bool read_verse_acl (void * webserver_request)
+bool read_verse_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) return true;
+  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ()))
+    return true;
   auto [ read, write ] = access_bible::any (webserver_request);
   return read;
 }
 
 
-string read_verse (void * webserver_request)
+std::string read_verse (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
   // Only act if a verse was found
-  string sverse = request->query ["verse"];
+  std::string sverse = webserver_request.query ["verse"];
   if (!sverse.empty ()) {
     
     // Only update navigation in case the verse changed.
     // This avoids unnecessary focus operations in the clients.
     int iverse = filter::strings::convert_to_int (sverse);
-    if (iverse != Ipc_Focus::getVerse (request)) {
-      int book = Ipc_Focus::getBook (request);
-      int chapter = Ipc_Focus::getChapter (request);
-      Ipc_Focus::set (request, book, chapter, iverse);
+    if (iverse != Ipc_Focus::getVerse (webserver_request)) {
+      int book = Ipc_Focus::getBook (webserver_request);
+      int chapter = Ipc_Focus::getChapter (webserver_request);
+      Ipc_Focus::set (webserver_request, book, chapter, iverse);
     }
   }
   
-  return "";
+  return std::string();
 }
