@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_RESOURCE_IMG_H
-#define INCLUDED_RESOURCE_IMG_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string resource_img_url ();
-bool resource_img_acl (void * webserver_request);
-string resource_img (void * webserver_request);
-
-
-#endif
+std::string resource_img_url ();
+bool resource_img_acl (Webserver_Request& webserver_request);
+std::string resource_img (Webserver_Request& webserver_request);
