@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -33,51 +33,47 @@
 #include <access/logic.h>
 #include <database/userresources.h>
 #include <database/books.h>
-using namespace std;
 
 
-string resource_user1view_url ()
+std::string resource_user1view_url ()
 {
   return "resource/user1view";
 }
 
 
-bool resource_user1view_acl (void * webserver_request)
+bool resource_user1view_acl (Webserver_Request& webserver_request)
 {
   return access_logic::privilege_view_resources (webserver_request);
 }
 
 
-string resource_user1view (void * webserver_request)
+std::string resource_user1view (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  
-  
-  string page {};
-  Assets_Header header = Assets_Header (translate("Resources"), request);
+  std::string page {};
+  Assets_Header header = Assets_Header (translate("Resources"), webserver_request);
   header.set_navigator ();
   header.add_bread_crumb (menu_logic_translate_menu (), menu_logic_translate_text ());
   page = header.run ();
   Assets_View view {};
   
 
-  string name = request->query ["name"];
+  std::string name = webserver_request.query ["name"];
 
   
-  vector <string> code {};
-  string url = Database_UserResources::url (name);
+  std::vector <std::string> code {};
+  std::string url = Database_UserResources::url (name);
   code.push_back ("var userResourceUrl = \"" + url + "\";");
   code.push_back ("var userResourceBooks = [];");
-  vector <book_id> ids = database::books::get_ids ();
+  std::vector <book_id> ids = database::books::get_ids ();
   for (auto id : ids) {
     book_type type = database::books::get_type (id);
     if ((type == book_type::old_testament) || (type == book_type::new_testament)) {
-      string book = Database_UserResources::book (name, static_cast<int> (id));
-      if (book.empty ()) book = convert_to_string (static_cast<int>(id));
-      code.push_back ("userResourceBooks [" + convert_to_string (static_cast<int>(id)) + "] = \"" + book + "\";");
+      std::string book = Database_UserResources::book (name, static_cast<int> (id));
+      if (book.empty ()) book = std::to_string (static_cast<int>(id));
+      code.push_back ("userResourceBooks [" + std::to_string (static_cast<int>(id)) + "] = \"" + book + "\";");
     }
   }
-  string script = filter_string_implode (code, "\n");
+  std::string script = filter::strings::implode (code, "\n");
   config::logic::swipe_enabled (webserver_request, script);
   view.set_variable ("script", script);
   
