@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,18 +29,17 @@ const char * session_logout_url ()
 }
 
 
-bool session_logout_acl (void * webserver_request)
+bool session_logout_acl (Webserver_Request& webserver_request)
 {
   return Filter_Roles::access_control (webserver_request, Filter_Roles::guest ());
 }
 
 
-string session_logout (void * webserver_request)
+std::string session_logout (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-  request->session_logic ()->logout ();
-  redirect_browser (request, index_index_url ());
-  return "";
+  webserver_request.session_logic ()->logout ();
+  redirect_browser (webserver_request, index_index_url ());
+  return std::string();
 }
 
 
