@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2020 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-#ifndef INCLUDED_SESSION_LOGOUT_H
-#define INCLUDED_SESSION_LOGOUT_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
 const char * session_logout_url ();
-bool session_logout_acl (void * webserver_request);
-string session_logout (void * webserver_request);
-
-
-#endif
+bool session_logout_acl (Webserver_Request& webserver_request);
+std::string session_logout (Webserver_Request& webserver_request);
