@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -32,40 +32,38 @@
 #include <pugixml.hpp>
 #endif
 #pragma GCC diagnostic pop
-using namespace std;
-using namespace pugi;
 
 
 // Local declarations.
-void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, xml_node node);
-void sources_morphhb_parse_unhandled_node (int book, int chapter, int verse, xml_node node);
+void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, pugi::xml_node node);
+void sources_morphhb_parse_unhandled_node (int book, int chapter, int verse, pugi::xml_node node);
 void sources_morphhb_parse ();
 
 
-void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, xml_node node)
+void sources_morphhb_parse_w_element (Database_OsHb * database_oshb, int book, int chapter, int verse, pugi::xml_node node)
 {
-  string lemma = node.attribute ("lemma").value ();
-  string word = node.child_value ();
+  std::string lemma = node.attribute ("lemma").value ();
+  std::string word = node.child_value ();
   word = filter::strings::replace ("/", "", word);
   database_oshb->store (book, chapter, verse, lemma, word, "");
 }
 
 
-void sources_morphhb_parse_unhandled_node (int book, int chapter, int verse, xml_node node)
+void sources_morphhb_parse_unhandled_node (int book, int chapter, int verse, pugi::xml_node node)
 {
-  string passage = filter_passage_display (book, chapter, filter::strings::convert_to_string (verse));
-  string text = node.child_value ();
-  cerr << "Unhandled " << node.name () << " at " << passage << ": " << text << endl;
+  std::string passage = filter_passage_display (book, chapter, std::to_string (verse));
+  std::string text = node.child_value ();
+  std::cerr << "Unhandled " << node.name () << " at " << passage << ": " << text << std::endl;
 }
 
 
 void sources_morphhb_parse ()
 {
-  cout << "Starting" << endl;
+  std::cout << "Starting" << std::endl;
   Database_OsHb database_oshb;
   database_oshb.create ();
 
-  vector <string> books = {
+  std::vector <std::string> books = {
     "Gen",
     "Exod",
     "Lev",
@@ -109,52 +107,52 @@ void sources_morphhb_parse ()
 
   for (size_t bk = 0; bk < books.size (); bk++) {
     
-    string file = "sources/morphhb/" + books[bk] + ".xml";
-    cout << file << endl;
+    std::string file = "sources/morphhb/" + books[bk] + ".xml";
+    std::cout << file << std::endl;
 
     int book = static_cast<int>(bk + 1);
 
-    xml_document document;
+    pugi::xml_document document;
     document.load_file (file.c_str());
-    xml_node osis_node = document.first_child ();
-    xml_node osisText_node = osis_node.child ("osisText");
-    xml_node div_book_node = osisText_node.child ("div");
-    for (xml_node chapter_node : div_book_node.children()) {
-      for (xml_node verse_node : chapter_node.children ()) {
-        string node_name = verse_node.name ();
+    pugi::xml_node osis_node = document.first_child ();
+    pugi::xml_node osisText_node = osis_node.child ("osisText");
+    pugi::xml_node div_book_node = osisText_node.child ("div");
+    for (pugi::xml_node chapter_node : div_book_node.children()) {
+      for (pugi::xml_node verse_node : chapter_node.children ()) {
+        std::string node_name = verse_node.name ();
         if (node_name != "verse") continue;
 
         // Get the passage.
-        string osisID = verse_node.attribute ("osisID").value ();
-        vector <string> bits = filter::strings::explode (osisID, '.');
+        std::string osisID = verse_node.attribute ("osisID").value ();
+        std::vector <std::string> bits = filter::strings::explode (osisID, '.');
         int chapter = filter::strings::convert_to_int (bits[1]);
         int verse = filter::strings::convert_to_int (bits[2]);
 
         bool word_stored = false;
         
         // Most of the nodes will be "w" but there's more nodes as well, see the source XML file.
-        for (xml_node node : verse_node.children ()) {
+        for (pugi::xml_node node : verse_node.children ()) {
 
           if (word_stored) database_oshb.store (book, chapter, verse, "", " ", "");
 
-          string child_node_name = node.name ();
+          std::string child_node_name = node.name ();
 
           if (child_node_name == "w") {
             sources_morphhb_parse_w_element (&database_oshb, book, chapter, verse, node);
           }
           
           else if (child_node_name == "seg") {
-            string word = node.child_value ();
+            std::string word = node.child_value ();
             database_oshb.store (book, chapter, verse, "", word, "");
           }
           
           else if (child_node_name == "note") {
-            for (xml_node variant_node : node.children ()) {
-              string variant_node_name = variant_node.name ();
+            for (pugi::xml_node variant_node : node.children ()) {
+              std::string variant_node_name = variant_node.name ();
               if (variant_node_name == "catchWord") {
                 sources_morphhb_parse_w_element (&database_oshb, book, chapter, verse, node);
               } else if (variant_node_name == "rdg") {
-                for (xml_node w_node : variant_node.children ()) {
+                for (pugi::xml_node w_node : variant_node.children ()) {
                   database_oshb.store (book, chapter, verse, "", "/", "");
                   sources_morphhb_parse_w_element (&database_oshb, book, chapter, verse, w_node);
                 }
@@ -176,5 +174,5 @@ void sources_morphhb_parse ()
   }
 
   database_oshb.optimize ();
-  cout << "Completed" << endl;
+  std::cout << "Completed" << std::endl;
 }
