@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2023 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -29,9 +29,9 @@
 #include <quill/logic.h>
 
 
-Styles_Css::Styles_Css (void* webserver_request, const std::string& stylesheet)
+Styles_Css::Styles_Css (Webserver_Request& webserver_request, const std::string& stylesheet):
+m_webserver_request (webserver_request)
 {
-  m_webserver_request = webserver_request;
   m_stylesheet = stylesheet;
 }
 
@@ -60,10 +60,9 @@ void Styles_Css::generate ()
   if (editor_enabled) {
     add_editor_styles ();
   }
-  Webserver_Request * request = static_cast<Webserver_Request *>(m_webserver_request);
-  std::vector <std::string> markers = request->database_styles ()->getMarkers (m_stylesheet);
+  std::vector <std::string> markers = m_webserver_request.database_styles ()->getMarkers (m_stylesheet);
   for (const auto& marker : markers) {
-    Database_Styles_Item style = request->database_styles ()->getMarkerData (m_stylesheet, marker);
+    Database_Styles_Item style = m_webserver_request.database_styles ()->getMarkerData (m_stylesheet, marker);
     evaluate (&style);
   }
 }
@@ -195,7 +194,7 @@ void Styles_Css::add (void * database_styles_item, bool paragraph, bool keepwith
     float percents {points * 100 / 12};
     int fontsize = filter::strings::convert_to_int (percents);
     if (fontsize != 100) {
-      m_code.push_back ("font-size: " + filter::strings::convert_to_string (fontsize) + "%;");
+      m_code.push_back ("font-size: " + std::to_string (fontsize) + "%;");
     }
   }
   
@@ -335,7 +334,13 @@ void Styles_Css::add_exports_styles ()
   m_code.push_back ("body { }");
   m_code.push_back ("p { margin-top: 0; margin-bottom: 0; }");
   m_code.push_back ("p.page { page-break-after: always; }");
-  m_code.push_back ("span.dropcaps { float: left; font-size: 300%; line-height: 0.85em; margin-right: 0.03em; margin-bottom:-0.25em; }");
+  // Old way of having dropcaps in the html export.
+  // But this has problem with negative indent like in poetry, visible in many Psalms.
+  // See issue https://github.com/bibledit/cloud/issues/905
+  // m_code.push_back ("span.dropcaps { float: left; font-size: 300%; line-height: 0.85em; margin-right: 0.03em; margin-bottom:-0.25em; }");
+  // New way of having dropcaps.
+  // Property "vertical-align: top;" could have been added, but then without it, it looks more beautify.
+  m_code.push_back (".dropcaps:nth-of-type(1) { font-size: 300%; line-height: 0.85em; margin-right: 0.03em; margin-bottom:-0.25em; }");
   m_code.push_back ("a { text-decoration: none; background: none; }");
   m_code.push_back ("a:visited { color: #5a3696; }");
   m_code.push_back ("a:active { color: #faa700; }");
@@ -359,7 +364,7 @@ void Styles_Css::customize (const std::string& bible)
   std::string font = fonts::logic::get_text_font (bible);
   bool uploaded_font = fonts::logic::font_exists (font);
   font = fonts::logic::get_font_path (font);
-  int direction = Database_Config_Bible::getTextDirection (bible);
+  int direction = database::config::bible::get_text_direction (bible);
   std::string css = Filter_Css::get_css (cls, font, direction);
   if (uploaded_font) css = filter::strings::replace ("../fonts/", "", css);
   m_code.push_back (css);
