@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2020 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,15 +17,11 @@
  */
 
 
-#ifndef INCLUDED_SYNC_CHANGES_H
-#define INCLUDED_SYNC_CHANGES_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string sync_changes_url ();
-string sync_changes (void * webserver_request);
-
-
-#endif
+std::string sync_changes_url ();
+std::string sync_changes (Webserver_Request& webserver_request);
