@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2024 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -30,5 +30,3 @@ void system_logic_import_notes_file (std::string tarball);
 std::string system_logic_resources_file_name (std::string resourcename = "");
 void system_logic_produce_resources_file (int jobid);
 void system_logic_import_resources_file (std::string tarball);
-void system_logic_indonesian_free_deletion (std::string username, std::string email);
-void system_logic_indonesian_free_expiration ();
