@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2024 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,25 +17,28 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
+#include <webserver/webserver.h>
 #include <webserver/http.h>
 #include <bootstrap/bootstrap.h>
 #include <webserver/request.h>
 #include <config/globals.h>
 #include <database/logs.h>
-#include <webserver/io.h>
 #include <filter/string.h>
 #include <filter/url.h>
 #include <filter/date.h>
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wswitch-enum"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #include <mbedtls/entropy.h>
 #include <mbedtls/ctr_drbg.h>
 #include <mbedtls/certs.h>
 #include <mbedtls/x509.h>
 #include <mbedtls/x509_crt.h>
 #include <mbedtls/ssl.h>
-// #include <mbedtls/ssl_tls.h>
 #include <mbedtls/net_sockets.h>
 #include <mbedtls/error.h>
 #include <mbedtls/ssl_cache.h>
+#pragma GCC diagnostic pop
 #ifdef HAVE_WINDOWS
 #include <io.h>
 #endif
@@ -52,22 +55,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //             the buffer to save the data to
 //             the size of the buffer
 // Returns: the number of bytes stored (excluding null).
-int get_line (int sock, char *buf, int size)
+static int get_line (const int sock, char *buf, const int size)
 {
-  int i = 0;
-  char character = '\0';
-  int n = 0;
+  int i {0};
+  char character {'\0'};
+  int n {0};
   while ((i < size - 1) && (character != '\n')) {
-    n = (int) recv (sock, &character, 1, 0);
+    n = static_cast<int> (::recv (sock, &character, 1, 0));
     if (n > 0) {
       if (character == '\r') {
-        /*
-        // Work around MSG_PEEK failure in nacl_io library.
-        // On Chrome OS the order is \r\n.
-        // So it's safe to throw the \r away, as we're sure the \n follows.
-        continue;
-        */
-        n = (int) recv (sock, &character, 1, MSG_PEEK);
+        n = static_cast<int> (recv (sock, &character, 1, MSG_PEEK));
         if ((n > 0) && (character == '\n')) {
           recv (sock, &character, 1, 0);
         } else {
@@ -85,13 +82,29 @@ int get_line (int sock, char *buf, int size)
 }
 
 
+// This converts an IPv4 address in IPv6 notation to a pure IPv4 notation.
+static void convert_ipv6_notation_to_pure_ipv4_notation (std::string& address)
+{
+  // The client's remote IPv6 address in hexadecimal digits separated by colons.
+  // IPv4 addresses are mapped to IPv6 addresses.
+  // Example IPv4 address: ::ffff:127.0.0.1
+  // Example IPv6 address: ::1
+  // Clean the IP address up so it's a clear IPv4 or IPv6 notation.
+  if (size_t pos = address.find(".");
+      pos != std::string::npos) {
+    pos = address.find_last_of(":");
+    address.erase (0, ++pos);
+  }
+}
+
+
 // Processes a single request from a web client.
-void webserver_process_request (int connfd, string clientaddress)
+static void webserver_process_request (const int connfd, const std::string& clientaddress)
 {
   // The environment for this request.
-  // A pointer to it gets passed around from function to function during the entire request.
+  // It reference to this object gets passed around from function to function during the entire request.
   // This provides thread-safety to the request.
-  Webserver_Request request;
+  Webserver_Request request {};
   
   // This is the plain http server.
   request.secure = false;
@@ -103,7 +116,7 @@ void webserver_process_request (int connfd, string clientaddress)
     if (config_globals_webserver_running) {
       
       // Connection health flag.
-      bool connection_healthy = true;
+      bool connection_healthy {true};
       
       // Read the client's request.
       // With the HTTP protocol it is not possible to read the request till EOF,
@@ -113,8 +126,8 @@ void webserver_process_request (int connfd, string clientaddress)
       // Read one line of data from the client.
       // An empty line marks the end of the headers.
 #define BUFFERSIZE 2048
-      int bytes_read;
-      bool header_parsed = true;
+      int bytes_read {};
+      bool header_parsed {true};
       char buffer [BUFFERSIZE];
       // Fix valgrind unitialized value message.
       memset (&buffer, 0, BUFFERSIZE);
@@ -122,7 +135,7 @@ void webserver_process_request (int connfd, string clientaddress)
         bytes_read = get_line (connfd, buffer, BUFFERSIZE);
         if (bytes_read <= 0) connection_healthy = false;
         // Parse the browser's request's headers.
-        header_parsed = http_parse_header (buffer, &request);
+        header_parsed = http_parse_header (buffer, request);
       } while (header_parsed);
 
       if (connection_healthy) {
@@ -130,12 +143,12 @@ void webserver_process_request (int connfd, string clientaddress)
         // In the case of a POST request, more data follows: The POST request itself.
         // The length of that data is indicated in the header's Content-Length line.
         // Read that data, and parse it.
-        string postdata;
+        std::string postdata {};
         if (request.is_post) {
-          bool done_reading = false;
-          int total_bytes_read = 0;
+          bool done_reading {false};
+          int total_bytes_read {0};
           do {
-            bytes_read = (int)recv(connfd, buffer, BUFFERSIZE, 0);
+            bytes_read = static_cast<int> (recv(connfd, buffer, BUFFERSIZE, 0));
             for (int i = 0; i < bytes_read; i++) {
               postdata += buffer [i];
             }
@@ -152,11 +165,11 @@ void webserver_process_request (int connfd, string clientaddress)
         
         if (connection_healthy) {
           
-          http_parse_post (postdata, &request);
+          http_parse_post (postdata, request);
           
           // Assemble response.
-          bootstrap_index (&request);
-          http_assemble_response (&request);
+          bootstrap_index (request);
+          http_assemble_response (request);
           
           // Send response to browser.
           const char * output = request.reply.c_str();
@@ -179,17 +192,17 @@ void webserver_process_request (int connfd, string clientaddress)
 #endif
             (request.stream_file.c_str(), O_RDONLY);
             unsigned char streambuffer [1024];
-            int bytecount;
+            int bytecount {};
             do {
-              bytecount = (int)
+              bytecount = static_cast<int> (
 #ifdef HAVE_WINDOWS
               _read
 #else
               read
 #endif
-              (filefd, streambuffer, 1024);
+              (filefd, streambuffer, 1024));
               if (bytecount > 0) {
-                [[maybe_unused]] auto sendbytes = send (connfd, (const char *)streambuffer, static_cast<size_t>(bytecount), 0);
+                [[maybe_unused]] auto sendbytes = send (connfd, reinterpret_cast<const char *> (streambuffer), static_cast<size_t>(bytecount), 0);
               }
             }
             while (bytecount > 0);
@@ -203,15 +216,18 @@ void webserver_process_request (int connfd, string clientaddress)
         }
       }
     }
-  } catch (exception & e) {
-    string message ("Internal error: ");
+  } 
+  catch (const std::exception& e) {
+    std::string message ("Internal error: ");
     message.append (e.what ());
     Database_Logs::log (message);
-  } catch (exception * e) {
-    string message ("Internal error: ");
+  } 
+  catch (const std::exception* e) {
+    std::string message ("Internal error: ");
     message.append (e->what ());
     Database_Logs::log (message);
-  } catch (...) {
+  } 
+  catch (...) {
     Database_Logs::log ("A general internal error occurred");
   }
   
@@ -230,23 +246,23 @@ void webserver_process_request (int connfd, string clientaddress)
 // This http server uses BSD sockets.
 void http_server ()
 {
-  bool listener_healthy = true;
+  bool listener_healthy {true};
 
   // Create a listening socket.
   // This represents an endpoint.
   // This prepares to accept incoming connections on.
 #ifdef HAVE_CLIENT
   // A client listens on IPv4, see also below.
-  int listenfd = socket (AF_INET, SOCK_STREAM, 0);
+  const int listenfd = socket (AF_INET, SOCK_STREAM, 0);
 #endif
 #ifdef HAVE_CLOUD
   // The Cloud listens on address family AF_INET6 for both IPv4 and IPv6.
-  int listenfd = socket (AF_INET6, SOCK_STREAM, 0);
+  const int listenfd = socket (AF_INET6, SOCK_STREAM, 0);
 #endif
   if (listenfd < 0) {
-    string error = "Error opening socket: ";
+    std::string error = "Error opening socket: ";
     error.append (strerror (errno));
-    cerr << error << endl;
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
@@ -254,12 +270,12 @@ void http_server ()
   // Eliminate "Address already in use" error from bind.
   // The function is used to allow the local address to  be reused
   // when the server is restarted before the required wait time expires.
-  int optval = 1;
-  int result = setsockopt (listenfd, SOL_SOCKET, SO_REUSEADDR, (const char *) &optval, sizeof (int));
+  int optval {1};
+  int result = setsockopt (listenfd, SOL_SOCKET, SO_REUSEADDR, reinterpret_cast<const char *> ( &optval), sizeof (int));
   if (result != 0) {
-    string error = "Error setting socket option: ";
+    std::string error = "Error setting socket option: ";
     error.append (strerror (errno));
-    cerr << error << endl;
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
   }
 
@@ -271,22 +287,22 @@ void http_server ()
   memset (&serveraddr, 0, sizeof (serveraddr));
   serveraddr.sin_family = AF_INET;
   serveraddr.sin_addr.s_addr = htonl (INADDR_LOOPBACK);
-  serveraddr.sin_port = htons (convert_to_int (config_logic_http_network_port ()));
+  serveraddr.sin_port = htons (filter::strings::convert_to_int (config::logic::http_network_port ()));
 #endif
 #ifdef HAVE_CLOUD
   // When configured as a server it listens on any IPv6 address.
-  struct sockaddr_in6 serveraddr;
+  sockaddr_in6 serveraddr;
   memset (&serveraddr, 0, sizeof (serveraddr));
   serveraddr.sin6_flowinfo = 0;
   serveraddr.sin6_family = AF_INET6;
   serveraddr.sin6_addr = in6addr_any;
-  serveraddr.sin6_port = htons (convert_to_int (config_logic_http_network_port ()));
+  serveraddr.sin6_port = htons (static_cast<uint16_t>(filter::strings::convert_to_int (config::logic::http_network_port ())));
 #endif
-  result = mybind (listenfd, (struct sockaddr *) &serveraddr, sizeof (serveraddr));
+  result = ::bind (listenfd, reinterpret_cast<sockaddr *>(&serveraddr), sizeof (serveraddr));
   if (result != 0) {
-    string error = "Error binding server to socket: ";
+    std::string error = "Error binding server to socket: ";
     error.append (strerror (errno));
-    cerr << error << endl;
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
@@ -295,9 +311,9 @@ void http_server ()
   // before the system starts rejecting the incoming requests.
   result = listen (listenfd, 100);
   if (result != 0) {
-    string error = "Error listening on socket: ";
+    std::string error = "Error listening on socket: ";
     error.append (strerror (errno));
-    cerr << error << endl;
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
@@ -306,33 +322,36 @@ void http_server ()
   while (listener_healthy && config_globals_webserver_running) {
 
     // Socket and file descriptor for the client connection.
-    struct sockaddr_in6 clientaddr6;
+    sockaddr_in6 clientaddr6;
     socklen_t clientlen = sizeof (clientaddr6);
-    int connfd = accept (listenfd, (struct sockaddr *)&clientaddr6, &clientlen);
+    int connfd = accept (listenfd, reinterpret_cast<sockaddr *>(&clientaddr6), &clientlen);
     if (connfd > 0) {
 
       // Socket receive timeout, plain http.
-      struct timeval tv;
+      timeval tv;
       tv.tv_sec = 60;
       tv.tv_usec = 0;
       setsockopt (connfd, SOL_SOCKET, SO_RCVTIMEO, &tv, sizeof(tv));
       
       // The client's remote IPv6 address in hexadecimal digits separated by colons.
       // IPv4 addresses are mapped to IPv6 addresses.
-      string clientaddress;
+      // Example IPv4 address: ::ffff:127.0.0.1
+      // Example IPv6 address: ::1
+      // Clean the IP address up so it's a clear IPv4 or IPv6 notation.
       char remote_address[256];
       inet_ntop (AF_INET6, &clientaddr6.sin6_addr, remote_address, sizeof (remote_address));
-      clientaddress = remote_address;
-      
+      std::string clientaddress = remote_address;
+      convert_ipv6_notation_to_pure_ipv4_notation (clientaddress);
+
       // Handle this request in a thread, enabling parallel requests.
-      thread request_thread = thread (webserver_process_request, connfd, clientaddress);
+      std::thread request_thread = std::thread (webserver_process_request, connfd, clientaddress);
       // Detach and delete thread object.
       request_thread.detach ();
       
     } else {
-      string error = "Error accepting connection on socket: ";
+      std::string error = "Error accepting connection on socket: ";
       error.append (strerror (errno));
-      cerr << error << endl;
+      std::cerr << error << std::endl;
       Database_Logs::log (error);
     }
   }
@@ -344,8 +363,8 @@ void http_server ()
 
 
 #ifdef HAVE_WINDOWS
-bool server_accepting_flag = false;
-mutex server_accepting_mutex;
+bool server_accepting_flag {false};
+std::mutex server_accepting_mutex;
 
 
 void http_server_acceptor_processor (SOCKET listen_socket)
@@ -370,7 +389,7 @@ void http_server_acceptor_processor (SOCKET listen_socket)
     setsockopt (client_socket, SOL_SOCKET, SO_RCVTIMEO, tv, sizeof (tv));
 
     // The client's remote IPv4 address in dotted notation.
-    string clientaddress;
+    std::string clientaddress;
     char remote_address[256];
     inet_ntop (AF_INET, &clientaddr.sin_addr.s_addr, remote_address, sizeof (remote_address));
     clientaddress = remote_address;
@@ -396,15 +415,15 @@ void http_server ()
   WSADATA wsa_data;
   result = WSAStartup(MAKEWORD(2, 2), &wsa_data);
   if (result != 0) {
-    string error = "Could not initialize Windows Sockets with error " + convert_to_string (result);
-    cerr << error << endl;
+    std::string error = "Could not initialize Windows Sockets with error " + filter::strings::convert_to_string (result);
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
   // Check for the correct requested Windows Sockets interface version.
   if (LOBYTE(wsa_data.wVersion) != 2 || HIBYTE(wsa_data.wVersion) != 2) {
-    string error = "Incorrect Windows Sockets version";
-    cerr << error << endl;
+    std::string error = "Incorrect Windows Sockets version";
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
@@ -412,8 +431,8 @@ void http_server ()
   // Create a socket for listening for incoming connections.
   SOCKET listen_socket = socket(AF_INET, SOCK_STREAM, 0);
   if (listen_socket == INVALID_SOCKET) {
-    string error = "Socket failed with error " + convert_to_string (WSAGetLastError());
-    cerr << error << endl;
+    std::string error = "Socket failed with error " + filter::strings::convert_to_string (WSAGetLastError());
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
@@ -425,11 +444,11 @@ void http_server ()
   memset(&serveraddr, 0, sizeof(serveraddr));
   serveraddr.sin_family = AF_INET;
   serveraddr.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
-  serveraddr.sin_port = htons(convert_to_int(config_logic_http_network_port()));
-  result = mybind(listen_socket, (SA *)&serveraddr, sizeof(serveraddr));
+  serveraddr.sin_port = htons(filter::strings::convert_to_int(config::logic::http_network_port()));
+  result = ::bind(listen_socket, (SA *)&serveraddr, sizeof(serveraddr));
   if (result == SOCKET_ERROR) {
-	  string error = "Error binding server to socket";
-    cerr << error << endl;
+	  std::string error = "Error binding server to socket";
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
 	  listener_healthy = false;
   }
@@ -437,8 +456,8 @@ void http_server ()
   // Listen for multiple connections.
   result = listen(listen_socket, SOMAXCONN);
   if (result == SOCKET_ERROR) {
-    string error = "Listen failed with error " + convert_to_string (WSAGetLastError());
-    cerr << error << endl;
+    std::string error = "Listen failed with error " + filter::strings::convert_to_string (WSAGetLastError());
+    std::cerr << error << std::endl;
     Database_Logs::log (error);
     listener_healthy = false;
   }
@@ -454,12 +473,12 @@ void http_server ()
     server_accepting_mutex.unlock ();
     if (start_acceptor) {
       // Handle waiting for and processing the request in a thread, enabling parallel requests.
-      thread request_thread = thread (http_server_acceptor_processor, listen_socket);
+      std::thread request_thread = std::thread (http_server_acceptor_processor, listen_socket);
       // Detach and delete thread object.
       request_thread.detach ();
     }
     // Wait shortly before next poll iteration.
-    this_thread::sleep_for (chrono::milliseconds (10));
+    std::this_thread::sleep_for (std::chrono::milliseconds (10));
   }
   
   // No longer need server socket
@@ -472,11 +491,11 @@ void http_server ()
 
 
 // Processes a single request from a web client.
-void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_context client_fd)
+static void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_context client_fd)
 {
   // Socket receive timeout, secure https.
 #ifndef HAVE_WINDOWS
-  struct timeval tv;
+  timeval tv;
   tv.tv_sec = 60;
   tv.tv_usec = 0;
   setsockopt (client_fd.fd, SOL_SOCKET, SO_RCVTIMEO, &tv, sizeof(tv));
@@ -485,7 +504,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
   // The environment for this request.
   // It gets passed around from function to function during the entire request.
   // This provides thread-safety to the request.
-  Webserver_Request request;
+  Webserver_Request request {};
   
   // This is the secure http server.
   request.secure = true;
@@ -498,13 +517,24 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
 
     if (config_globals_webserver_running) {
 
-      // Get client's remote IPv4 address in dotted notation and put it in the webserver request object.
-      struct sockaddr_in addr;
-      socklen_t addr_size = sizeof(struct sockaddr_in);
-      getpeername (client_fd.fd, (struct sockaddr *)&addr, &addr_size);
-      char remote_address [256];
-      inet_ntop (AF_INET, &addr.sin_addr.s_addr, remote_address, sizeof (remote_address));
-      request.remote_address = remote_address;
+      // Get the client's remote IPv4 address in dotted notation,
+      // or the IPv6 address in the proper notation,
+      // and put it in the webserver request object.
+      {
+        sockaddr_storage client_addr;
+        socklen_t socklen = sizeof(client_addr);
+        getpeername(client_fd.fd, reinterpret_cast<sockaddr *>(&client_addr), &socklen);
+        char remote_address [256];
+        if (client_addr.ss_family == AF_INET) {
+          struct sockaddr_in *s = reinterpret_cast<sockaddr_in *>(&client_addr);
+          inet_ntop(AF_INET, &s->sin_addr, remote_address, sizeof remote_address);
+        } else if(client_addr.ss_family == AF_INET6) {
+          struct sockaddr_in6 *s = reinterpret_cast<sockaddr_in6 *>(&client_addr);
+          inet_ntop(AF_INET6, &s->sin6_addr, remote_address, sizeof remote_address);
+        }
+        request.remote_address = remote_address;
+        convert_ipv6_notation_to_pure_ipv4_notation (request.remote_address);
+      }
       
       // This flag indicates a healthy connection: One that can proceed.
       bool connection_healthy = true;
@@ -514,13 +544,13 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
       if (connection_healthy) {
         ret = mbedtls_ssl_setup (&ssl, conf);
         if (ret != 0) {
-          filter_url_display_mbed_tls_error (ret, NULL, true);
+          filter_url_display_mbed_tls_error (ret, nullptr, true, request.remote_address);
           connection_healthy = false;
         }
       }
       
       if (connection_healthy) {
-        mbedtls_ssl_set_bio (&ssl, &client_fd, mbedtls_net_send, mbedtls_net_recv, NULL);
+        mbedtls_ssl_set_bio (&ssl, &client_fd, mbedtls_net_send, mbedtls_net_recv, nullptr);
       }
       
       // SSL / TLS handshake.
@@ -529,7 +559,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           if (config_globals_webserver_running) {
             // In case the secure server runs, display the error.
             // And in case the server is interrupted by e.g. Ctrl-C, don't display this error.
-            filter_url_display_mbed_tls_error (ret, NULL, true);
+            filter_url_display_mbed_tls_error (ret, nullptr, true, request.remote_address);
           }
           connection_healthy = false;
         }
@@ -537,7 +567,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
       
       // Read the HTTP headers.
       bool header_parsed = true;
-      string header_line;
+      std::string header_line {};
       while (connection_healthy && header_parsed) {
         // Read the client's request.
         // With the HTTP protocol it is not possible to read the request till EOF,
@@ -562,7 +592,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           if (c == '\r') continue;
           // At a new line, parse the received header line.
           if (c == '\n') {
-            header_parsed = http_parse_header (header_line, &request);
+            header_parsed = http_parse_header (header_line, request);
             header_line.clear ();
           } else {
             header_line += c;
@@ -576,7 +606,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         // The POST request itself.
         // The length of that data is indicated in the header's Content-Length line.
         // Read that data.
-        string postdata;
+        std::string postdata{};
         bool done_reading = false;
         int total_bytes_read = 0;
         while (connection_healthy && !done_reading) {
@@ -598,19 +628,19 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         if (total_bytes_read < request.content_length) connection_healthy = false;
         // Parse the POSTed data.
         if (connection_healthy) {
-          http_parse_post (postdata, &request);
+          http_parse_post (postdata, request);
         }
       }
       
       // Assemble response.
       if (connection_healthy) {
-        bootstrap_index (&request);
-        http_assemble_response (&request);
+        bootstrap_index (request);
+        http_assemble_response (request);
       }
       
       // Write the response to the browser.
       const char * output = request.reply.c_str();
-      const unsigned char * buf = (const unsigned char *) output;
+      const unsigned char * buf = reinterpret_cast<const unsigned char *>(output);
       // The C function strlen () fails on null characters in the reply, so take string::size()
       size_t len = request.reply.size ();
       while (connection_healthy && (len > 0)) {
@@ -631,7 +661,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
           // until it returns a positive value.
           if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
           if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
-          filter_url_display_mbed_tls_error (ret, NULL, true);
+          filter_url_display_mbed_tls_error (ret, nullptr, true, request.remote_address);
           connection_healthy = false;
         }
       }
@@ -650,15 +680,15 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         unsigned char buffer [1024];
         int bytecount;
         do {
-          bytecount = (int)
+          bytecount = static_cast<int>(
 #ifdef HAVE_WINDOWS
           _read
 #else
           read
 #endif
-          (filefd, buffer, 1024);
+          (filefd, buffer, 1024));
           int remaining_length = bytecount;
-          const unsigned char * buffer_ptr = (const unsigned char *) &buffer;
+          const unsigned char * buffer_ptr = reinterpret_cast<const unsigned char *>(&buffer);
           while (connection_healthy && (remaining_length > 0)) {
             // Function
             // int ret = mbedtls_ssl_write (&ssl, buf, len)
@@ -677,7 +707,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
               // until it returns a positive value.
               if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
               if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
-              filter_url_display_mbed_tls_error (ret, NULL, true);
+              filter_url_display_mbed_tls_error (ret, nullptr, true, request.remote_address);
               connection_healthy = false;
             }
           }
@@ -696,7 +726,7 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         while ((ret = mbedtls_ssl_close_notify (&ssl)) < 0) {
           if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
           if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
-          filter_url_display_mbed_tls_error (ret, NULL, true);
+          filter_url_display_mbed_tls_error (ret, nullptr, true, request.remote_address);
           connection_healthy = false;
           if (connection_healthy) {}; // Suppress static analyzer warning about unused code.
           break;
@@ -704,15 +734,18 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
       }
       
     }
-  } catch (exception & e) {
-    string message ("Internal error: ");
+  } 
+  catch (const std::exception& e) {
+    std::string message ("Internal error: ");
     message.append (e.what ());
     Database_Logs::log (message);
-  } catch (exception * e) {
-    string message ("Internal error: ");
+  } 
+  catch (const std::exception * e) {
+    std::string message ("Internal error: ");
     message.append (e->what ());
     Database_Logs::log (message);
-  } catch (...) {
+  } 
+  catch (...) {
     Database_Logs::log ("A general internal error occurred");
   }
   
@@ -732,10 +765,46 @@ void https_server ()
 #ifdef RUN_SECURE_SERVER
 
   // The https network port to listen on.
-  // Port "0..9" means: Don't run the secure web server.
-  string network_port = config_logic_https_network_port ();
+  // Port 0..9 means this:: Don't run the secure web server.
+  const std::string network_port = config::logic::https_network_port ();
   if (network_port.length() <= 1) return;
   
+  // Check whether all the certificates are there and can be read.
+  // If not, log some feedback and don't run the secure web server.
+  const std::string server_key_path {config::logic::server_key_path (false)};
+  const std::string server_certificate_path {config::logic::server_certificate_path (false)};
+  const std::string authorities_certificates_path {config::logic::authorities_certificates_path (false)};
+  if (!server_key_path.empty()) {
+    const std::string contents {filter_url_file_get_contents (server_key_path)};
+    if (contents.empty()) {
+      Database_Logs::log("Cannot read " + server_key_path + " so not running secure server");
+      return;
+    }
+  } else {
+    Database_Logs::log("Cannot find server private key in " + config::logic::server_key_path (true) + " so not running secure server");
+    return;
+  }
+  if (!server_certificate_path.empty()) {
+    const std::string contents {filter_url_file_get_contents (server_certificate_path)};
+    if (contents.empty()) {
+      Database_Logs::log("Cannot read " + server_certificate_path + " so not running secure server");
+      return;
+    }
+  } else {
+    Database_Logs::log("Cannot find server certificate in " + config::logic::server_certificate_path (true) + " so not running secure server");
+    return;
+  }
+  if (!authorities_certificates_path.empty()) {
+    std::string contents {filter_url_file_get_contents (authorities_certificates_path)};
+    if (contents.empty()) {
+      Database_Logs::log("Cannot read " + authorities_certificates_path + " so not running secure server");
+      return;
+    }
+  } else {
+    Database_Logs::log("Cannot find certificate authorities chain in " + config::logic::authorities_certificates_path (true) + " so not running secure server");
+    return;
+  }
+  
   // File descriptor for the listener.
   mbedtls_net_context listen_fd;
   mbedtls_net_init (&listen_fd);
@@ -755,60 +824,75 @@ void https_server ()
   mbedtls_ctr_drbg_context ctr_drbg;
   mbedtls_ctr_drbg_init (&ctr_drbg);
 
-  int ret;
-  string path;
-  
   // Load the private RSA server key.
   mbedtls_pk_context pkey;
   mbedtls_pk_init (&pkey);
-  path = config_logic_server_key_path ();
-  ret = mbedtls_pk_parse_keyfile (&pkey, path.c_str (), NULL);
-  if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
+  int ret = mbedtls_pk_parse_keyfile (&pkey, server_key_path.c_str (), nullptr);
+  if (ret != 0) {
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
+    Database_Logs::log("Invalid " + server_key_path + " so not running secure server");
+    return;
+  }
   
   // Server certificates store.
   mbedtls_x509_crt srvcert;
   mbedtls_x509_crt_init (&srvcert);
   
   // Load the server certificate.
-  path = config_logic_server_certificate_path ();
-  ret = mbedtls_x509_crt_parse_file (&srvcert, path.c_str ());
-  if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
+  ret = mbedtls_x509_crt_parse_file (&srvcert, server_certificate_path.c_str ());
+  if (ret != 0) {
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
+    Database_Logs::log("Invalid " + server_certificate_path + " so not running secure server");
+    return;
+  }
 
   // Load the chain of certificates of the certificate authorities.
-  path = config_logic_authorities_certificates_path ();
-  ret = mbedtls_x509_crt_parse_file (&srvcert, path.c_str ());
-  if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
+  ret = mbedtls_x509_crt_parse_file (&srvcert, authorities_certificates_path.c_str ());
+  if (ret != 0) {
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
+    Database_Logs::log("Invalid " + authorities_certificates_path + " so not running secure server");
+    return;
+  }
 
   // Seed the random number generator.
   const char *pers = "Cloud";
-  ret = mbedtls_ctr_drbg_seed( &ctr_drbg, mbedtls_entropy_func, &entropy, (const unsigned char *) pers, strlen (pers));
+  ret = mbedtls_ctr_drbg_seed (&ctr_drbg, mbedtls_entropy_func, &entropy, reinterpret_cast<const unsigned char *> (pers), strlen (pers));
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
     return;
   }
   
   // Setup the listening TCP socket.
-  ret = mbedtls_net_bind (&listen_fd, NULL, network_port.c_str (), MBEDTLS_NET_PROTO_TCP);
+  ret = mbedtls_net_bind (&listen_fd, nullptr, network_port.c_str (), MBEDTLS_NET_PROTO_TCP);
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
     return;
   }
   
   // Setup SSL/TLS default values for the lifetime of the https server.
   ret = mbedtls_ssl_config_defaults (&conf, MBEDTLS_SSL_IS_SERVER, MBEDTLS_SSL_TRANSPORT_STREAM, MBEDTLS_SSL_PRESET_DEFAULT);
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
     return;
   }
   mbedtls_ssl_conf_rng (&conf, mbedtls_ctr_drbg_random, &ctr_drbg);
   mbedtls_ssl_conf_session_cache (&conf, &cache, mbedtls_ssl_cache_get, mbedtls_ssl_cache_set);
-  mbedtls_ssl_conf_ca_chain (&conf, srvcert.next, NULL);
+  mbedtls_ssl_conf_ca_chain (&conf, srvcert.next, nullptr);
   ret = mbedtls_ssl_conf_own_cert (&conf, &srvcert, &pkey);
   if (ret != 0) {
-    filter_url_display_mbed_tls_error (ret, NULL, true);
+    filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
     return;
   }
   
+  // Whether the plain http server redirects to secure http.
+  // Possible automatic forwarding from http to https is postponed till here
+  // because only here it is known whether the https server runs at all.
+  // https://github.com/bibledit/cloud/issues/866
+  config_globals_enforce_https_browser = config::logic::enforce_https_browser ();
+  config_globals_enforce_https_client = config::logic::enforce_https_client ();
+
+  std::cout << "Listening on https://localhost:" << network_port << std::endl;
+  
   // Keep preparing for, accepting, and processing client connections.
   while (config_globals_webserver_running) {
     
@@ -817,14 +901,14 @@ void https_server ()
     mbedtls_net_init (&client_fd);
     
     // Wait until a client connects.
-    ret = mbedtls_net_accept (&listen_fd, &client_fd, NULL, 0, NULL);
+    ret = mbedtls_net_accept (&listen_fd, &client_fd, nullptr, 0, nullptr);
     if (ret != 0 ) {
-      filter_url_display_mbed_tls_error (ret, NULL, true);
+      filter_url_display_mbed_tls_error (ret, nullptr, true, std::string());
       continue;
     }
-    
+
     // Handle this request in a thread, enabling parallel requests.
-    thread request_thread = thread (secure_webserver_process_request, &conf, client_fd);
+    std::thread request_thread = std::thread (secure_webserver_process_request, &conf, client_fd);
     // Detach and delete thread object.
     request_thread.detach ();
   }
@@ -832,7 +916,7 @@ void https_server ()
   // Wait shortly to give sufficient time to let the connection fail,
   // before the local SSL/TLS variables get out of scope,
   // which would lead to a segmentation fault if those variables were still in use.
-  this_thread::sleep_for (chrono::milliseconds (5));
+  std::this_thread::sleep_for (std::chrono::milliseconds (5));
 
   // Close listening socket, freeing it for a possible subsequent server process.
   mbedtls_net_free (&listen_fd);
